//
//  ClassroomJoinViewController.m
//  TICDemo
//
//  Created by jameskhdeng(邓凯辉) on 2018/5/15.
//  Copyright © 2018年 Tencent. All rights reserved.
//

#import "ClassroomJoinViewController.h"
#import "ClassroomViewController.h"
#import "JMLoadingHUD.h"
#import "JMToast.h"
#import "IMManager.h"
#import "BoardManager.h"
#import "TICDemoConst.h"


@interface ClassroomJoinViewController ()
@property (weak, nonatomic) IBOutlet UITextField *classIdTextField;
@property (weak, nonatomic) IBOutlet UITextField *imGroupTextField;
@property (weak, nonatomic) IBOutlet UITextField *nickNameTextField;

@property (weak, nonatomic) IBOutlet UITextField *courseUrlField;
@property (weak, nonatomic) IBOutlet UIProgressView *courseProgress;
@property (weak, nonatomic) IBOutlet UILabel *courseProgressLabel;
@property (assign, nonatomic)BOOL loadingCourse;

@property (weak, nonatomic) IBOutlet UITextField *customUrlField;
@property (weak, nonatomic) IBOutlet UIProgressView *customProgress;
@property (weak, nonatomic) IBOutlet UILabel *customProgressLabel;
@property (assign, nonatomic)BOOL loadingCustom;
@end

@implementation ClassroomJoinViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    [self.navigationItem setHidesBackButton:YES];
    self.title = self.userId;
    UIBarButtonItem *rightBarItem = [[UIBarButtonItem alloc] initWithTitle:NSLocalizedString(@"Exit", nil) style:UIBarButtonItemStylePlain target:self action:@selector(onLogout)];
    self.navigationItem.rightBarButtonItem = rightBarItem;
    
    TEduBoardResourceConfig *config = [[TEduBoardResourceConfig alloc] init];
    config.sdkAppId = kSDKAppId;
    config.userId = self.userId;
    [TEduBoardResourceController setConfig:config];
    NSString *lastClassId = [[NSUserDefaults standardUserDefaults] objectForKey:@"kLastClassId"];
    if (lastClassId.length > 0) {
        self.classIdTextField.text = lastClassId;
    }
}

- (UIInterfaceOrientationMask)supportedInterfaceOrientations
{
    return UIInterfaceOrientationMaskPortrait;
}

#pragma mark - ClassRoom
// 进入ClassroomViewController视图
- (void)enterClassRoom:(TEduBoardController *)boardController {
    NSString *classId = self.classIdTextField.text;
    NSString *userId = self.title;
    UIStoryboard *story = [UIStoryboard storyboardWithName:@"Main" bundle:[NSBundle mainBundle]];
    // 创建classRoom视图
    ClassroomViewController *classRoom = [story instantiateViewControllerWithIdentifier:@"ClassroomViewController"];
    classRoom.classId = classId;
    classRoom.userId = userId;
    classRoom.boardController = boardController;
    [self.navigationController pushViewController:classRoom animated:YES];
}

- (void)preloadTest {
    [TEduBoardResourceController loadCustomResource:@"https://res.qcloudtiw.com/demo/tiw-vod.mp4" resouceType:TEDU_BOARD_PRELOAD_RESOURCE_TYPE_MEDIA expireTime:259200 callback:^(NSString * _Nonnull url, NSInteger progress, NSError * _Nonnull error) {
        NSLog(NSLocalizedString(@"DownloadProgressWithError", nil), url, (long)progress, error);
    }];
    
    //    [TEduBoardResourceController loadResource:@"https://coscdn.51tyty.com/document/0dtf445stsh31794r27c_tiw/0dtf445stsh31794r27c.zip"];
}

- (IBAction)preloadCourse {
    NSString *url = [self.courseUrlField text];
    if (url.length <= 0) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"CoursewareUrlCannotBeEmpty", nil)];
        return;
    }
    if (![url.lowercaseString hasPrefix:@"http"]) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"CoursewareUrlSupportsHttpHttpsOnly", nil)];
        return;
    }
    if (self.loadingCourse) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"DownloadingPleaseWait", nil)];
        return;
    }
    self.loadingCourse = true;
    __weak typeof(self) ws = self;
    bool result = [TEduBoardResourceController loadResource:url expireTime:259200 callback:^(NSString * _Nonnull url, NSInteger progress, NSError * _Nonnull error) {
        NSLog(NSLocalizedString(@"DownloadProgressWithError", nil), url, (long)progress, error);
        ws.courseProgress.progress = (float)progress / 100.0;
        ws.courseProgressLabel.text = [NSString stringWithFormat:@"%ld%%", (long)progress];
        if (progress >= 100 || progress <= -1) {
            ws.loadingCourse = false;
        }
    }];
    if (!result) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"CoursewarePreloadFailedCheckUrl", nil)];
    }
}

- (IBAction)preloadCustomResource {
    NSString *url = [self.customUrlField text];
    if (url.length <= 0) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"CustomResourceUrlCannotBeEmpty", nil)];
        return;
    }
    if (![url.lowercaseString hasPrefix:@"http"]) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"CustomResourceUrlSupportsHttpHttpsOnly", nil)];
        return;
    }
    if (self.loadingCustom) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"DownloadingPleaseWait", nil)];
        return;
    }
    self.loadingCustom = true;
    __weak typeof(self) ws = self;
    bool result = [TEduBoardResourceController loadCustomResource:url resouceType:TEDU_BOARD_PRELOAD_RESOURCE_TYPE_MEDIA expireTime:259200 callback:^(NSString * _Nonnull url, NSInteger progress, NSError * _Nonnull error) {
        NSLog(NSLocalizedString(@"DownloadProgressWithError", nil), url, (long)progress, error);
        ws.customProgress.progress = (float)progress / 100.0;
        ws.customProgressLabel.text = [NSString stringWithFormat:@"%ld%%", (long)progress];
        if (progress >= 100 || progress <= -1) {
            ws.loadingCustom = false;
        }
    }];
    if (!result) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"CustomResourceLoadFailedCheckUrl", nil)];
    }
}
// 加入课堂
- (IBAction)onJoinClass:(id)sender {
    NSString *imGroupId = self.imGroupTextField.text;
    NSString *classId = self.classIdTextField.text;
    NSString *nickName = self.nickNameTextField.text;
    
    if (classId.length <= 0) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"RoomNumberCannotBeEmpty", nil)];
        return;
    }
    if (imGroupId.length <= 0) {
        imGroupId = classId;
    }

    [JMLoadingHUD show];
    __weak typeof(self) ws = self;
    // 1、IM进群组
    [[IMManager sharedInstance] joinIMGroup:imGroupId callback:^(int code, NSString *desc) {
        if (code == 0) {
            // 2、创建白板
            [[NSUserDefaults standardUserDefaults] setObject:classId forKey:@"kLastClassId"];
            [[NSUserDefaults standardUserDefaults] synchronize];
            [[BoardManager sharedInstance] creteBoard:[NSString stringWithFormat:@"%ld", kSDKAppId]
                                                  userId:self.userId
                                                 userSig:self.userSig
                                                 classId:classId
                                            imGroupId:imGroupId
                                                nickName:nickName
                                                callback:^(int code, NSString * _Nullable desc, TEduBoardController * _Nullable boardController) {
                [JMLoadingHUD hide];
                if (code == 0) {
                    [ws enterClassRoom:boardController];
                }
                else {
                    [[JMToast sharedToast] showDialogWithMsg:[NSString stringWithFormat:NSLocalizedString(@"WhiteboardInitializationFailed", nil), code, desc]];
                }
            }];
        }
        else {
            [JMLoadingHUD hide];
            [[JMToast sharedToast] showDialogWithMsg:[NSString stringWithFormat:NSLocalizedString(@"JoinIMGroupFailed", nil), code, desc]];
        }
    }];
}

//退出登录
- (void)onLogout
{
    __weak typeof(self) ws = self;
    // 退出IM登录
    [[IMManager sharedInstance] logout:^(int code, NSString * _Nullable desc) {
        if (code == 0) {
            [ws.navigationController popViewControllerAnimated:YES];
        }
        else {
            [[JMToast sharedToast] showDialogWithMsg:[NSString stringWithFormat:@"退出课堂失败：%d %@", code, desc]];
        }
    }];
}
@end
