#define SCREEN_WIDTH [[UIScreen mainScreen] bounds].size.width
#define SCREEN_HEIGHT [[UIScreen mainScreen] bounds].size.height
#define kBoardH ceil([[UIScreen mainScreen] bounds].size.width*9/16.0)
#define kVideoH ceil([[UIScreen mainScreen] bounds].size.width*1/5.0)

#import "ClassroomViewController.h"
#import "UIViewController+Utils.h"
#import "MenuTableViewController.h"
#import "IMManager.h"
#import "BoardManager.h"
#import "JMToast.h"
#import "PopWebView.h"
#import "AppDelegate.h"

static const NSString *staticClassID = @"";
static NSString *kUpdateElementUrl = nil;
static NSString *kPermissionUrl = nil;
static NSString *kAddWatermarkUrl = nil;
static NSString *kAddVideoFileUrl = nil;
static NSString *kAddH5FileUrl = nil;
static NSString *kAddTransCodeFileUrl = nil;

// static NSString *kUpdateElementUrl = @"http://localhost:8080/#/UpdateElement";
// static NSString *kPermissionUrl = @"http://localhost:8080/#/Permission";
// static NSString *kAddWatermarkUrl = @"http://localhost:8080/#/AddWatermark";
// static NSString *kAddVideoFileUrl = @"http://localhost:8080/#/AddVideoFile";

@interface ClassroomViewController () <UITextFieldDelegate, MenuTableViewControllerDelegate, TEduBoardDelegate, IMManagerListener, PopWebViewDelegate>
//白板视图容器
@property (weak, nonatomic) IBOutlet UIView *boardViewContainer;
//菜单控制器
@property (nonatomic, strong) MenuTableViewController *menuController;
@property(nonatomic, strong)PopWebView *popWebview;
@property(nonatomic, strong)TEduBoardElement *currentElement;
@property(nonatomic, strong)NSArray<TEduBoardElementInfo *>  *selectElements;
@property(nonatomic, assign)NSTimeInterval lastPermissionToast;
@property(nonatomic, strong)IBOutlet UIImageView *imgView;
@property(nonatomic, strong) NSDictionary *permissionDic;
@property(nonatomic, strong) NSString *dataExported;
@property(nonatomic, strong)IBOutlet UITextView *chatView;
@property(nonatomic, assign)Boolean autoSelect;

@end

@implementation ClassroomViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    kUpdateElementUrl = NSLocalizedString(@"UpdateElementUrl", nil);
    kPermissionUrl = NSLocalizedString(@"PermissionUrl", nil);
    kAddWatermarkUrl = NSLocalizedString(@"AddWatermarkUrl", nil);
    kAddVideoFileUrl = NSLocalizedString(@"AddVideoFileUrl", nil);
    kAddH5FileUrl = NSLocalizedString(@"AddH5FileUrl", nil);
    kAddTransCodeFileUrl = NSLocalizedString(@"AddTranscodeFile", nil);
    self.title = _classId;
    
    //初始化菜单控制器
    UIStoryboard *story = [UIStoryboard storyboardWithName:@"Main" bundle:[NSBundle mainBundle]];
    self.menuController = [story instantiateViewControllerWithIdentifier:@"MenuTableViewController"];
    self.menuController.delegate = self;
    self.menuController.view.frame = CGRectMake(self.view.bounds.size.width / 2, 0, self.view.bounds.size.width / 2, self.view.bounds.size.height);
    [self addChildViewController:self.menuController];
    [self.view addSubview:self.menuController.view];
    self.menuController.view.hidden = YES;
    
    //初始化导航栏
    UIBarButtonItem *lefBarItem = [[UIBarButtonItem alloc] initWithTitle:NSLocalizedString(@"ExitClassroom", nil) style:UIBarButtonItemStylePlain target:self action:@selector(onQuitClassRoom)];
    self.navigationItem.leftBarButtonItem = lefBarItem;
    UIBarButtonItem *rightBarItem = [[UIBarButtonItem alloc] initWithTitle:NSLocalizedString(@"Menu", nil) style:UIBarButtonItemStylePlain target:self action:@selector(onMenu)];
    self.navigationItem.rightBarButtonItem = rightBarItem;
    
    //监听事件键盘
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(keyboardWillShow:)
                                                 name:UIKeyboardWillShowNotification
                                               object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(keyboardWillHide:)
                                                 name:UIKeyboardDidHideNotification
                                               object:nil];
    
    //白板视图
    [self.boardController addDelegate:self];
    UIView *boardView = [self.boardController getBoardRenderView];
    self.automaticallyAdjustsScrollViewInsets = NO;
    if (@available(iOS 11.0, *)) {
        ((WKWebView*)boardView).scrollView.contentInsetAdjustmentBehavior = UIScrollViewContentInsetAdjustmentNever;
    }
    boardView.frame = CGRectMake(0, 0, [UIScreen mainScreen].bounds.size.width, [UIScreen mainScreen].bounds.size.width * 9 / 16);
    [self.boardViewContainer addSubview:boardView];
    [IMManager sharedInstance].delegate = self;
    //    [self.boardViewContainer setBackgroundColor:[UIColor orangeColor]];
    [[self.boardController getBoardRenderView] setOpaque:NO];
    [[self.boardController getBoardRenderView] setBackgroundColor:[UIColor clearColor]];
    self.boardViewContainer.clipsToBounds = YES;
    if ([[[UIDevice currentDevice] systemVersion] floatValue] < 15.0) {
        [self rotateToLandscape:YES];
    }
    [self.boardController setScrollBarVisible:YES];
    
}
- (UIInterfaceOrientationMask)supportedInterfaceOrientations {
    return UIInterfaceOrientationMaskLandscapeRight;
}


- (void)rotateToLandscape:(BOOL)landscape {
    
    UIInterfaceOrientation curOrt = [UIApplication sharedApplication].statusBarOrientation;
    UIDeviceOrientation devOrt = [UIDevice currentDevice].orientation;
    
    if (landscape) {
        if (!UIInterfaceOrientationIsLandscape(curOrt)) {
            NSNumber *orientationUnknown = [NSNumber numberWithInt:UIInterfaceOrientationUnknown];
            [[UIDevice currentDevice] setValue:orientationUnknown forKey:@"orientation"];
            if (UIDeviceOrientationIsLandscape(devOrt)) {
                NSNumber *orientationTarget = [NSNumber numberWithInt:(int)devOrt];
                [[UIDevice currentDevice] setValue:orientationTarget forKey:@"orientation"];
            } else {
                int tarOrt = UIInterfaceOrientationLandscapeRight;
                NSNumber *orientationTarget = [NSNumber numberWithInt:tarOrt];
                [[UIDevice currentDevice] setValue:orientationTarget forKey:@"orientation"];
            }
            
        }
    } else {
        if (!UIInterfaceOrientationIsPortrait(curOrt) && !UIDeviceOrientationIsLandscape(devOrt)) {
            NSNumber *orientationUnknown = [NSNumber numberWithInt:UIInterfaceOrientationUnknown];
            [[UIDevice currentDevice] setValue:orientationUnknown forKey:@"orientation"];
            
            if (UIDeviceOrientationIsLandscape(devOrt)) {
                NSNumber *orientationTarget = [NSNumber numberWithInt:(int)devOrt];
                [[UIDevice currentDevice] setValue:orientationTarget forKey:@"orientation"];
            } else {
                int tarOrt = UIInterfaceOrientationPortrait;
                NSNumber *orientationTarget = [NSNumber numberWithInt:tarOrt];
                [[UIDevice currentDevice] setValue:orientationTarget forKey:@"orientation"];
            }
            
        }
    }
}

- (void)viewWillLayoutSubviews {
    [super viewWillLayoutSubviews];
    NSString *ratio = [self.boardController getBoardRatio];
    float fRatio = 4.0 / 3.0;
    if ([ratio isEqualToString:@"16:9"]) {
        fRatio = 16.0 / 9.0;
    }
    CGRect contentframe = self.view.frame;
    if (@available(iOS 11.0, *)) {
        contentframe.origin.y += self.view.safeAreaInsets.top;
        contentframe.size.height -= (self.view.safeAreaInsets.top + self.view.safeAreaInsets.bottom);
    }
    float height = contentframe.size.height;
    float width =  ceilf(height * fRatio);
    float x = (contentframe.size.width - width) / 2;
    float y = contentframe.origin.y;
    if(width > contentframe.size.width) {
        width = contentframe.size.width;
        height = ceilf(width / fRatio);
        x = contentframe.origin.x;
        y = (contentframe.size.height - height) / 2 + contentframe.origin.y;
    }
    self.boardViewContainer.frame = CGRectMake(x, y, width, height);
    for (UIView *subview in [self.boardViewContainer subviews]) {
        subview.frame = self.boardViewContainer.bounds;
    }
    self.menuController.view.frame = CGRectMake(self.view.bounds.size.width / 2, 0, self.view.bounds.size.width / 2, self.view.bounds.size.height);
}

- (void)openPopWebview:(NSString *)url {
    // 先关闭 再打开
    [self closePopWebview];
    
    self.popWebview = [[PopWebView alloc] init];
    self.popWebview.delegate = self;
    [self.view addSubview:self.popWebview];
    self.popWebview.frame = self.view.bounds;
    [self.popWebview loadUrl:url];
}

- (void)closePopWebview {
    if (self.popWebview) {
        [self.popWebview removeFromSuperview];
        [self.popWebview unInit];
        self.popWebview = nil;
    }
}

- (void)reciverH5Msg:(NSString* _Nonnull)action data:(NSDictionary *_Nonnull)data {
    if ([action isEqualToString:@"setElementStyle"]) {
        int styleType = [[data objectForKey:@"styleType"] intValue];
        if (styleType == TEduElementOperatorTypeElementDelete) {
            for (int i = 0; i < self.selectElements.count; i++) {
                [self.boardController updateElementById:self.selectElements[i].elementId  type:styleType value:@""];
            }
            [self closePopWebview];
        }
        else if(styleType == TEduElementOperatorTypePosition) {
            NSDictionary *dic = [data objectForKey:@"styleValue"];
            CGPoint point = CGPointMake([[dic objectForKey:@"x"] floatValue], [[dic objectForKey:@"y"] floatValue]);
            [self.boardController updateElementById:self.currentElement.elementId position:point];
        }
        else {
            NSString *styleValue = [NSString stringWithFormat:@"%@", [data objectForKey:@"styleValue"]];
            [self.boardController updateElementById:self.currentElement.elementId  type:styleType value:styleValue];
        }
    }
    else if ([action isEqualToString:@"addVideoFile"]) {
        NSDictionary *dic = [data objectForKey:@"value"];
        NSString *url = [dic objectForKey:@"url"];
        NSString *title = [dic objectForKey:@"title"];
        [self.boardController addVideoFile:url title:title needSwitch:YES];
    }
    else if ([action isEqualToString:@"addElement"]) {
        NSDictionary *dic = [data objectForKey:@"value"];
        NSInteger type = [[data objectForKey:@"type"] intValue];
        if (type == TEDU_BOARD_ELEMENT_WATERMARK) {
            TEduBoardElementWatermark *params = [[TEduBoardElementWatermark alloc] init];
            params.content = [dic objectForKey:@"content"];
            params.left = [dic objectForKey:@"left"];
            params.top = [dic objectForKey:@"top"];
            params.width = [dic objectForKey:@"width"];
            params.height = [dic objectForKey:@"height"];
            params.opacity = [[dic objectForKey:@"opacity"] floatValue];
            [self.boardController addElementWithWatermark:params options:nil];
        }
    }
    else if ([action isEqualToString:@"closeWebview"]) {
        [self closePopWebview];
    }
    else if ([action isEqualToString:@"showToast"]) {
        if ([data objectForKey:@"content"]) {
            [[JMToast sharedToast] showDialogWithMsg:[data objectForKey:@"content"]];
        }
    }
    else if([action isEqualToString:@"setPermission"]) {
        NSDictionary *content = [data objectForKey:@"content"];
        if(content && [content isKindOfClass:NSDictionary.class]) {
            [self setPermission:content];
        }
        [self closePopWebview];
    }
    else if ([action isEqualToString:@"addH5File"]) {
        NSDictionary *dic = [data objectForKey:@"value"];
        NSString *url = [dic objectForKey:@"url"];
        NSString *title = [dic objectForKey:@"title"];
        NSString *angle = [NSString stringWithFormat:@"%@", [dic objectForKey:@"angle"]];
        NSString *boardId = [self.boardController addElement:url type:TEDU_BOARD_ELEMENT_H5];
        [self.boardController updateElementById:boardId type:TEduElementOperatorTypeRotationAngle value:angle];
        //        [[BoardManager sharedInstance].boardController addH5File:url title:title needSwitch:YES];
    }
    else if ([action isEqualToString:@"addTransCodeFile"]) {
        NSDictionary *dic = [data objectForKey:@"value"];
        NSString *url = [dic objectForKey:@"url"];
        NSString *title = [dic objectForKey:@"title"];
        NSInteger pages =  [[dic objectForKey:@"pages"] integerValue];
        
        TEduBoardTranscodeFileResult *result = [[TEduBoardTranscodeFileResult alloc] init];
        result.url = url;
        result.pages = pages;
        result.title = title;
        [self.boardController addTranscodeFile:result needSwitch:YES];
    }
}

- (void)setPermission:(NSDictionary *)permissionData {
    self.permissionDic = permissionData;
    NSDictionary *permissionMap = @{
        NSLocalizedString(@"SetBackgroundColor", nil): @"Background::Update::Color", NSLocalizedString(@"SetBackgroundFrame", nil): @"Background::Update::Frame",
        NSLocalizedString(@"SetBackgroundImage", nil): @"Background::Update::Image", NSLocalizedString(@"AddWhiteboard", nil): @"Board::Add",
        NSLocalizedString(@"ClearWhiteboard", nil): @"Board::Clear", NSLocalizedString(@"DeleteWhiteboard", nil): @"Board::Delete",
        NSLocalizedString(@"ZoomWhiteboard", nil): @"Board::Scale::*", NSLocalizedString(@"SwitchWhiteboard", nil): @"Board::Switch::Page",
        NSLocalizedString(@"SwitchStep", nil): @"Board::Switch::Step", NSLocalizedString(@"UpdateWhiteboardContentFillMode", nil): @"Board::Update::ContentFitMode",
        NSLocalizedString(@"UpdateWhiteboardRatio", nil): @"Board::Update::Ratio", NSLocalizedString(@"AddElement", nil): @"Element::Add::*",
        NSLocalizedString(@"DeleteElement", nil): @"Element::Delete::*", NSLocalizedString(@"SelectElement", nil): @"Element::Select::*",
        NSLocalizedString(@"UpdateElement", nil): @"Element::Update::*", NSLocalizedString(@"AddFile", nil): @"File::Add",
        NSLocalizedString(@"ClearFile", nil): @"File::Clear", NSLocalizedString(@"DeleteFile", nil): @"File::Delete",
        NSLocalizedString(@"SwitchFile", nil): @"File::Switch", NSLocalizedString(@"UpdateFile", nil): @"File::Update::*",
        NSLocalizedString(@"SetInstanceProperties", nil): @"Instance::Configure::*", NSLocalizedString(@"ResetWhiteboard", nil): @"Instance::Reset",
        NSLocalizedString(@"Undo", nil): @"Board::Undo::*", NSLocalizedString(@"Redo", nil): @"Board::Redo::*",
    };
    NSMutableArray *havePermissionArray = [NSMutableArray array];
    NSMutableArray *noPermissionArray = [NSMutableArray array];
    NSMutableArray *disableArray = [NSMutableArray array];
    NSArray *array = [permissionData objectForKey:@"backgroundCheckList"];
    if([permissionData objectForKey:@"background"]
       && array && [array isKindOfClass:NSArray.class]) {
        NSArray *background = @[NSLocalizedString(@"SetBackgroundColor", nil), NSLocalizedString(@"SetBackgroundFrame", nil), NSLocalizedString(@"SetBackgroundImage", nil)];
        if([[permissionData objectForKey:@"background"] intValue] == 1) {
            // 开启了背景权限校验
            for (NSString *key in background) {
                NSString *value = [permissionMap objectForKey:key];
                if([array containsObject:key]) {
                    [havePermissionArray addObject:value];
                }
                else {
                    [noPermissionArray addObject:value];
                }
            }
        }
        else {
            // 关闭了背景权限校验
            [disableArray addObject:@"Background::*"];
        }
    }
    
    array = [permissionData objectForKey:@"boardCheckList"];
    if([permissionData objectForKey:@"board"]
       && array && [array isKindOfClass:NSArray.class]) {
        NSArray *board = @[NSLocalizedString(@"AddWhiteboard", nil), NSLocalizedString(@"ClearWhiteboard", nil), NSLocalizedString(@"DeleteWhiteboard", nil), NSLocalizedString(@"ZoomWhiteboard", nil), NSLocalizedString(@"SwitchWhiteboard", nil), NSLocalizedString(@"SwitchStep", nil), NSLocalizedString(@"UpdateWhiteboardContentFillMode", nil), NSLocalizedString(@"UpdateWhiteboardRatio", nil), NSLocalizedString(@"Undo", nil), NSLocalizedString(@"Redo", nil), NSLocalizedString(@"ResetWhiteboard", nil)];
        if([[permissionData objectForKey:@"board"] intValue] == 1) {
            // 开启了白板权限校验
            for (NSString *key in board) {
                NSString *value = [permissionMap objectForKey:key];
                if([array containsObject:key]) {
                    [havePermissionArray addObject:value];
                }
                else {
                    [noPermissionArray addObject:value];
                }
            }
        }
        else {
            // 关闭了白板权限校验
            [disableArray addObject:@"Board::*"];
        }
    }
    
    array = [permissionData objectForKey:@"elementCheckList"];
    if([permissionData objectForKey:@"element"]
       && array && [array isKindOfClass:NSArray.class]) {
        NSArray *board = @[NSLocalizedString(@"AddElement", nil), NSLocalizedString(@"DeleteElement", nil), NSLocalizedString(@"SelectElement", nil), NSLocalizedString(@"UpdateElement", nil)];
        if([[permissionData objectForKey:@"element"] intValue] == 1) {
            // 开启了元素权限校验
            for (NSString *key in board) {
                NSString *value = [permissionMap objectForKey:key];
                if([array containsObject:key]) {
                    [havePermissionArray addObject:value];
                }
                else {
                    [noPermissionArray addObject:value];
                }
            }
        }
        else {
            // 关闭了元素权限校验
            [disableArray addObject:@"Element::*"];
        }
    }
    
    array = [permissionData objectForKey:@"fileCheckList"];
    if([permissionData objectForKey:@"file"]
       && array && [array isKindOfClass:NSArray.class]) {
        NSArray *board = @[NSLocalizedString(@"AddFile", nil), NSLocalizedString(@"ClearFile", nil), NSLocalizedString(@"DeleteFile", nil), NSLocalizedString(@"SwitchFile", nil), NSLocalizedString(@"UpdateFile", nil)];
        if([[permissionData objectForKey:@"file"] intValue] == 1) {
            // 开启了文件权限校验
            for (NSString *key in board) {
                NSString *value = [permissionMap objectForKey:key];
                if([array containsObject:key]) {
                    [havePermissionArray addObject:value];
                }
                else {
                    [noPermissionArray addObject:value];
                }
            }
        }
        else {
            // 关闭了文件权限校验
            [disableArray addObject:@"File::*"];
        }
    }
    
    //    [self.boardController resetPermissionChecker];
    if(havePermissionArray.count > 0) {
        [self.boardController enablePermissionChecker:havePermissionArray filters:@[ [NSString stringWithFormat:@"operator/%@", self.userId]] ];
    }
    if(noPermissionArray.count > 0) {
        [self.boardController enablePermissionChecker:noPermissionArray filters:@[@"operator/"]];
    }
    if(disableArray.count > 0) {
        [self.boardController disablePermissionChecker:disableArray];
    }
}

#pragma mark - 白板回调
- (void)onTEBRedoStatusChanged:(BOOL)canRedo {
    [self.menuController setCanRedo:canRedo];
}

- (void)onTEBUndoStatusChanged:(BOOL)canUndo {
    [self.menuController setCanUndo:canUndo];
}

- (void)onTEBHistroyDataSyncCompleted {
    [self addMsgInChatView:NSLocalizedString(@"HistoryDataLoaded", nil)];
    float vlaue = [self.boardController getTextLineHeight];
    [self.menuController setTextHeight:vlaue];
}

//- (void)onTEBBoardDrawStatusChanged:(TEduBoardDrawStatusChanged)status {
//    [self addMsgInChatView: status == TEduBoardDrawStatusStart ? @"绘制开始" : @"绘制结束"];
//}

- (void)onTEBWarning:(TEduBoardWarningCode)code msg:(NSString *)msg {
    if (code == TEDU_BOARD_WARNING_IMAGE_WATERMARK_ALREADY_EXISTS) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"ImageWatermarkExists", nil)];
    } else if(code == TEDU_BOARD_WARNING_VIDEO_ALREADY_EXISTS) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"DuplicateFileAddition", nil)];
    } else if(code == TEDU_BOARD_WARNING_H5PPT_ALREADY_EXISTS) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"DuplicateFileAddition", nil)];
    } else if(code == TEDU_BOARD_WARNING_H5FILE_ALREADY_EXISTS) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"DuplicateFileAddition", nil)];
    } else if(code == TEDU_BOARD_WARNING_IMAGESFILE_ALREADY_EXISTS) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"DuplicateFileAddition", nil)];
    } else if(code == TEDU_BOARD_WARNING_IMAGE_COURSEWARE_ALREADY_EXISTS) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"DuplicateFileAddition", nil)];
    }
}

- (void)onTEBError:(TEduBoardErrorCode)code msg:(NSString *)msg {
    if (code == TEDU_BOARD_SIGNATURE_EXPIRED) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"UserSigExpired", nil)];
        [[BoardManager sharedInstance] destroyBoard];
        [[IMManager sharedInstance] kickout];
        [self closePopWebview];
        UIWindow *window = [(AppDelegate *)[UIApplication sharedApplication].delegate window];
        [(UINavigationController *)window.rootViewController popToRootViewControllerAnimated:YES];
    }
}

- (void)onTEBVideoStatusChanged:(NSString *)fileId status:(TEduBoardVideoStatus)status progress:(CGFloat)progress duration:(CGFloat)duration {
    if (status == TEDU_BOARD_VIDEO_STATUS_ERROR) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"VideoPlaybackLoadFailed", nil)];
    }
    NSLog(@"video progress = %.f", progress);
}

- (void)onTEBH5PPTStatusChanged:(NSString *)fileId
                         status:(TEduBoardH5PPTStatus)status
                        message:(NSString *)message {
    if (fileId.length > 0 && status == TEDU_BOARD_H5_PPT_STATUS_LOADED) {
        NSDictionary *dic = [self.boardController getPPTRemarks:fileId pageIndex:-1];
        NSMutableString *str = [NSMutableString stringWithString:@"getPPTRemarks: \n"];
        NSArray *array = [dic.allKeys sortedArrayUsingComparator:^NSComparisonResult(NSString  * obj1, NSString  *obj2) {
            return obj1.intValue > obj2.intValue;
        }];
        for (NSString *key in array) {
            if([key length] > 0 && [dic[key] length] > 0) {
                [str appendFormat:@"%@:%@", key, dic[key]];
            }
        }
        [self addMsgInChatView:str];
    } else {
        [self addMsgInChatView:[NSString stringWithFormat:@"H5PPTStatusChanged, fileId = %@, status = %ld, message = %@", fileId, (long)status, message]];
    }
}

- (void)onTEBSelectedElements:(NSArray<TEduBoardElementInfo *> *) selectedElements {
    self.selectElements = selectedElements;
    if (selectedElements.count > 0) {
        TEduBoardElementInfo *info = selectedElements[0];
        self.currentElement = [[BoardManager sharedInstance].boardController getElementById:info.elementId];
        [self openPopWebview:kUpdateElementUrl];
        NSMutableDictionary *params = [NSMutableDictionary dictionary];
        
        [params setObject:@(self.currentElement.type) forKey:@"type"];
        if (self.currentElement.title) {
            [params setObject:self.currentElement.title forKey:@"title"];
        }
        
        if (self.currentElement.style) {
            if (self.currentElement.style.borderColor) {
                NSString *borderColorKey = [NSString stringWithFormat:@"%ld", (long)TEduElementOperatorTypeBorderColor];
                [params setObject:self.currentElement.style.borderColor forKey:borderColorKey];
            }
            NSString *borderWidthKey = [NSString stringWithFormat:@"%ld", (long)TEduElementOperatorTypeBorderWidth];
            [params setObject:@(self.currentElement.style.borderWidth) forKey:borderWidthKey];
            
            NSString *borderTypeKey = [NSString stringWithFormat:@"%ld", (long)TEduElementOperatorTypeBorderLineType];
            [params setObject:@(self.currentElement.style.borderType) forKey:borderTypeKey];
        }
        NSString *positionKey = [NSString stringWithFormat:@"%ld", (long)TEduElementOperatorTypePosition];
        [params setObject:@{@"x": @(info.left), @"y": @(info.top)} forKey:positionKey];
        
        NSString *textSizeKey = [NSString stringWithFormat:@"%ld", (long)TEduElementOperatorTypeTextSize];
        [params setObject:@(self.currentElement.textSize) forKey:textSizeKey];
        
        [self.popWebview sendToH5:@"setElementInfo" params:params];
    }
}

- (void)onTEBElementsPositonChanged:(NSArray<TEduBoardElementInfo *> *)elements {
    if (elements.count > 0) {
        TEduBoardElementInfo *element = elements[0];
        NSLog(@"%.1f, %.1f, %.1f, %.1f", element.top, element.left, element.width, element.height);
    }
}

- (void)onTEBBoardPermissionDenied:(NSString *)permission {
    //    self.lastPermissionToast
    NSTimeInterval time = [[NSDate date] timeIntervalSince1970];
    if(time - self.lastPermissionToast > 2.0) {
        NSString *text = [NSString stringWithFormat:NSLocalizedString(@"OperationLacksPermission", nil), permission];
        [[JMToast sharedToast] showDialogWithMsg:text];
        self.lastPermissionToast = time;
    }
}

- (void)onTEBBoardScaleChanged:(NSString *)boardId scale:(double)scale xOffset:(double)xOffset yOffset:(double)yOffset {
    NSLog(@"BoardScaleChanged, boardId = %@, scale = %0.2f, xOffset = %0.2f, yOffset = %0.2f", boardId, scale, xOffset, yOffset);
    NSString *msg = [NSString stringWithFormat:NSLocalizedString(@"ReceivedWhiteboardZoomEvent", nil), boardId, scale, xOffset, yOffset];
    [self addMsgInChatView:msg];
}

- (void)onTEBAddTranscodeFile:(NSString *)fileId {
    NSString *msg = [NSString stringWithFormat:@"add Transcode File: %@", fileId];
    [self addMsgInChatView:msg];
}

- (void)onTEBAddElement:(NSString *)elementId url:(NSString *)url type:(TEduBoardElementType)type {
    NSString *msg = [NSString stringWithFormat:@"白板元素添加成功， elementId = %@， type = %d", elementId, (int)type];
    [self addMsgInChatView:msg];
    
    if (self.autoSelect && type == 13) {
        [self.boardController autoSelectedElement:elementId];
    }
}

- (void)onTEBSnapshot:(NSString *)path errorCode:(TEduBoardErrorCode)code errorMsg:(NSString *)msg {
    UIImage *image = [UIImage imageWithContentsOfFile:path];
    if(code == 0) {
        [self addMsgInChatView:@"截图成功，将保存至相册"];
    } else {
        [self addMsgInChatView:[NSString stringWithFormat:@"截图失败, code = %ld, msg = %@", (long)code, msg]];
    }
    
    if (image) {
        UIImageWriteToSavedPhotosAlbum(image, nil, nil, nil);
    } else {
        NSLog(@"Failed to load image from file.");
    }
}
#pragma mark - Api使用示例
// 添加文本元素
- (void)addTextElement {
    [self.boardController addTextElement:NSLocalizedString(@"IamTestText", nil) fontColor:@"#ff0000" fontSize:500 fontFace:@"PingFangSC-Regular" fontStyle:TEDU_BOARD_TEXT_STYLE_BOLD];
}

// 添加数学函数图像
- (void)addMathGraphElement {
    TEduBoardElementMathBoard *mathboard = [[TEduBoardElementMathBoard alloc] init];
    mathboard.axisColor = UIColor.orangeColor;
    NSString *boardid = [self.boardController addElementWithBoard:mathboard options:nil];
    TEduBoardElementMathGraph *mathGraph = [[TEduBoardElementMathGraph alloc] init];
    mathGraph.mathBoardId = [NSString stringWithFormat:@"%@", boardid];
    mathGraph.expression = @"cos(x)";
    mathGraph.color = UIColor.orangeColor;
    [self.boardController addElementWithGraph:mathGraph options:nil];
}

// 添加图片元素
- (void)addImageElement {
    TEduBoardAddElementOptions *op = [[TEduBoardAddElementOptions alloc] init];
    op.left = @"100px";
    op.top = @"100px";
    [self.boardController addElement:@"https://main.qcloudimg.com/raw/be5d8bc407204d0e1dea30bacd6d006b.png" type:TEDU_BOARD_ELEMENT_IMAGE options:op];
}

// 添加视频元素
- (void)addVideoElement {
    [self.boardController  addVideoFile:@"http://test-1259648581.cos.ap-shanghai.myqcloud.com/media/%5B%E6%B8%85%E6%99%B0%20480P%5D%20%E6%9C%AA%E6%9D%A5%E5%BB%BA%E7%AD%91-%E8%85%BE%E8%AE%AF%E6%BB%A8%E6%B5%B7%E5%A4%A7%E5%8E%A6.mp4" title:NSLocalizedString(@"TestVideo", nil) needSwitch:YES];
}

// 设置自定义字体
- (void)setCustomFont {
    [self.boardController addTextFontFamily:@"myFont" fontUrl:@"https://tic-res-1259648581.cos.ap-shanghai.myqcloud.com/board/dev_board/zhutao/fonts/XiaoDouDaoFengWuShiJianFan-Shan%28REEJI-Xiaodou-PoemGBT-Flash%29-2.ttf"];
    [self.boardController setTextFontFamily:@"myFont"];
    NSString *currentFont = [self.boardController getTextFontFamily];
    NSLog(@"currentFont = %@", currentFont);
}

// 添加公式元素
- (void)addExpressionElement {
    TEduBoardElementFormula *params = [[TEduBoardElementFormula alloc] init];
    params.expression = @"f(x) = \\\\int_{-\\\\infty}^\\\\infty \\\\hat{f}(\\\\xi)\\\\,e^{2 \\\\pi i \\\\xi x} \\\\,d\\\\xi";
    [self.boardController addElementWithFormula:params options:nil];
}

- (void)gotoPPTStep {
    NSArray<TEduBoardFileInfo *> *fileList = [self.boardController getFileInfoList];
    for (TEduBoardFileInfo *file in fileList) {
        if (TEduBoardFileTypeH5Courseware == file.fileType && file.boardInfoList.count > 0) {
            NSString *boardid = file.boardInfoList.firstObject.boardId;
            [self.boardController gotoStep:2 ofBoard:boardid];
        }
    }
}

- (void)addTranscodeFile {
    {
        TEduBoardTranscodeFileResult *result = [[TEduBoardTranscodeFileResult alloc] init];
        result.url = @"https://test-1259648581.file.myqcloud.com/ppt/0001nngov3gvpvfe9p5c/";
        result.pages = 137;
        //        result.resolution = @"959x539";
        result.title = NSLocalizedString(@"RedStarIlluminatesChinaPdf", nil);
        [self.boardController addTranscodeFile:result needSwitch:YES];
        //        dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(1 * NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
        //
        //        });
    }
    
    //    {
    //        TEduBoardTranscodeFileResult *result = [[TEduBoardTranscodeFileResult alloc] init];
    //        result.url = @"https://test-1259648581.file.myqcloud.com/ppt/000sedd4ish31fn0kq5c/index.html";
    //        result.pages = 72;
    //        result.resolution = @"960x540";
    //        result.title = NSLocalizedString(@"FifthLectureFinalDraftPptx", nil);
    //        dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(10 * NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
    //            [self.boardController addTranscodeFile:result needSwitch:YES];
    //        });
    //    }
    
}

- (void)onQuitClassRoom
{
    [self.boardController removeDelegate:self];
    [[NSNotificationCenter defaultCenter] removeObserver:self];
    
    [[BoardManager sharedInstance] destroyBoard];
    
    __weak typeof(self) ws = self;
    [IMManager sharedInstance].delegate = nil;
    [[IMManager sharedInstance] quitIMGroup:self.classId callback:^(int code, NSString * _Nullable desc) {
        if(code == 0){
            //退出课堂成功
        }
        else{
            //退出课堂失败
        }
        [ws.navigationController popViewControllerAnimated:YES];
    }];
}

- (void)onMenu
{
    self.menuController.view.hidden = !self.menuController.view.hidden;
}


#pragma mark - MenuTableViewController点击

- (void)onMagicPenChanged:(NSInteger)index {
    if(index == 0 ) {
        [self.boardController enablePenAutoFit:false delay:0];
        [self.boardController setPenAutoFittingMode:TEduBoardPenFittingModeNone];
    }
    else if (index == 1) {
        [self.boardController enablePenAutoFit:false delay:0];
        [self.boardController setPenAutoFittingMode:TEduBoardPenFittingModeAuto];
    }
    else if (index == 2) {
        [self.boardController setPenAutoFittingMode:TEduBoardPenFittingModeNone];
        [self.boardController enablePenAutoFit:true delay:2000];
    }
}

- (void)onMultiTouchChanged:(BOOL)state {
    [self.boardController enableMultiTouch:state];
    [self.boardController setSyncFps:10];
}

- (void)onDisableTouchChanged:(BOOL)state {
    //    [self.boardController onDisableTouchChanged:state];
    [self.boardController disablePointerEventResponding:state];
}

- (void)onPiecewiseErasureChanged:(BOOL)state {
    [self.boardController setPiecewiseErasureEnable:state];
}

- (void)onSelectToolType:(int)toolType
{
    NSInteger index = toolType;
    if (index >= TEDU_BOARD_TOOL_TYPE_RECT_SELECT) {
        index += 1;
    }
    if (index >= TEDU_BOARD_TOOL_TYPE_ARC) {
        index += 1;
    }
    TEduBoardGraphStyle *style= [[TEduBoardGraphStyle alloc] init];
    style.lineType = TEDU_BOARD_LINE_TYPE_SOLID;
    style.startArrowType = TEDU_BOARD_ARROW_TYPE_NONE;
    style.endArrowType = TEDU_BOARD_ARROW_TYPE_NONE;
    style.fillType = TEduBoardFillTypeNone;
    if (index == TEDU_BOARD_TOOL_TYPE_OVAL_SOLID
        || index == TEDU_BOARD_TOOL_TYPE_RECT_SOLID
        || index == TEDU_BOARD_TOOL_TYPE_SQUARE_SOLID
        || index == TEDU_BOARD_TOOL_TYPE_CIRCLE_SOLID) {
        style.fillType = TEduBoardFillTypeSolid;
    }
    [[BoardManager sharedInstance].boardController setGraphStyle:style];
    [[BoardManager sharedInstance].boardController setToolType:(TEduBoardToolType)index];
}

- (void)onSelectGraphStyle:(int)style {
    if (style == 0) {
        [self.boardController setGraphStyle:[TEduBoardGraphStyle dashedLineNoArrow]];
        [self.boardController setToolType: TEDU_BOARD_TOOL_TYPE_LINE];
    }
    else if (style == 1) {
        [self.boardController setGraphStyle:[TEduBoardGraphStyle solidLineEndArrow]];
        [self.boardController setToolType: TEDU_BOARD_TOOL_TYPE_LINE];
    }
    else if (style == 2) {
        [self.boardController setGraphStyle:[TEduBoardGraphStyle dashedLineStartArrow]];
        [self.boardController setToolType: TEDU_BOARD_TOOL_TYPE_LINE];
    }
    else if (style == 3) {
        [self.boardController setGraphStyle:[TEduBoardGraphStyle solidLineBothArrow]];
        [self.boardController setToolType: TEDU_BOARD_TOOL_TYPE_LINE];
    }
    else if (style == 4) {
        [self.boardController setGraphStyle:[TEduBoardGraphStyle solidTriangle]];
        [self.boardController setToolType: TEDU_BOARD_TOOL_TYPE_RIGHT_TRIANGLE];
    }
    else if (style == 5) {
        [self.boardController setGraphStyle:[TEduBoardGraphStyle dashedRect]];
        [self.boardController setToolType: TEDU_BOARD_TOOL_TYPE_RECT];
    }
    else if (style == 6) {
        //    [array addObject:NSLocalizedString(@"SolidIsoscelesTriangle", nil)];
        TEduBoardGraphStyle *style= [[TEduBoardGraphStyle alloc] init];
        style.fillType = TEduBoardFillTypeSolid;
        [self.boardController setGraphStyle:style];
        [self.boardController setToolType: TEDU_BOARD_TOOL_TYPE_ISOSCELES_TRIANGLE];
    }
    else if (style == 7) {
        //    [array addObject:NSLocalizedString(@"SolidRightAngleTriangle", nil)];
        TEduBoardGraphStyle *style= [[TEduBoardGraphStyle alloc] init];
        style.fillType = TEduBoardFillTypeSolid;
        [self.boardController setGraphStyle:style];
        [self.boardController setToolType: TEDU_BOARD_TOOL_TYPE_RIGHT_TRIANGLE];
    }
    else if (style == 8) {
        //    [array addObject:NSLocalizedString(@"SolidParallelogram", nil)];
        TEduBoardGraphStyle *style= [[TEduBoardGraphStyle alloc] init];
        style.fillType = TEduBoardFillTypeSolid;
        [self.boardController setGraphStyle:style];
        [self.boardController setToolType: TEDU_BOARD_TOOL_TYPE_PARALLELOGRAM];
    }
    __weak typeof(self) ws = self;
    dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(1 * NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
        NSDictionary *dic = [[ws.boardController getGraphStyle] performSelector:@selector(toJsonMap)];
        NSLog(@"getGraphStyle = %@", [dic description]);
    });
}

- (void)onSelectMathToolType:(int)toolType {
    [self.boardController useMathTool:(TEduMathToolType)toolType];
}

- (void)onSelectCustomGraph:(NSString *)url
{
    [self.boardController setToolType:TEDU_BOARD_TOOL_TYPE_BOARD_CUSTOM_GRAPH];
    [self.boardController addElement:url type:TEDU_BOARD_ELEMENT_CUSTOM_GRAPH];
}

- (void)onSelectBrushColor:(UIColor *)color
{
    [self.boardController setBrushColor:color];
}

- (void)onBrushThinChanged:(float)thin
{
    [self.boardController setBrushThin:thin];
}

- (void)onSnapshot:(BOOL)full {
    NSDate *now = [NSDate date];
    NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
    [dateFormatter setDateFormat:@"yyyyMMdd_HHmmss"];
    NSString *dateString = [dateFormatter stringFromDate:now];
    
    NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    NSString *documentsDirectory = [paths firstObject];
    
    NSString *pngPath = [documentsDirectory stringByAppendingPathComponent:[NSString stringWithFormat:@"%@.png", dateString]];
    
    TEduBoardSnapshotInfo *info = [[TEduBoardSnapshotInfo alloc] init];
    info.path = pngPath;
    info.full = full;
    [self.boardController snapshot:info];
}

- (void)onSelectTextColor:(UIColor *)color
{
    [self.boardController setTextColor:color];
}

- (void)onSelectFluorescentColor:(UIColor *)color
{
    const CGFloat *components = CGColorGetComponents(color.CGColor);
    float a = components[3];
    if (a < 0.1) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"HighlighterValueCannotBeLessThan10", nil)];
        return;
    }
    [self.boardController setHighlighterColor:color];
}

- (void)onSelectBackgroundColor:(UIColor *)color
{
    [self.boardController setBackgroundColor:color];
}

- (void)onSelectGlobalBackgroundColor:(UIColor *)color
{
    [self.boardController setGlobalBackgroundColor:color];
}

- (void)onTextSizeChanged:(float)thin
{
    [self.boardController setTextSize:thin];
}

- (void)onEraserSizeChanged:(float)size {
    [self.boardController setEraserSize:(NSInteger)size];
}

- (void)onTextHeightChanged:(float)height
{
    [self.boardController setTextLineHeight:height];
}

- (void)onDrawStateChanged:(BOOL)state
{
    [self.boardController setDrawEnable:state];
}

- (void)onSyncDataChanged:(BOOL)state
{
    [self.boardController setDataSyncEnable:state];
}

- (void)onAddElementAutoSelect:(BOOL)state {
    self.autoSelect = state;
}

- (void)onSetBackgroundH5:(NSString *)url
{
    [self.boardController setBackgroundH5:url];
}

- (void)onAddH5File:(NSInteger)index
{
    [self openPopWebview:kAddH5FileUrl];
    ////    [self.boardController addH5File:url title:@"" needSwitch:YES];
    //    NSString *elementId = [self.boardController addElement:@"https://www.qq.com" type:TEDU_BOARD_ELEMENT_H5];
    //    NSInteger angle = index * 5;
    //    [self.boardController updateElementById:elementId type:TEduElementOperatorTypeRotationAngle value:[NSString stringWithFormat:@"%ld", angle]];
}

- (void)onSetTextStyle:(int)style
{
    [self.boardController setTextStyle:(TEduBoardTextStyle)style];
}

- (void)onAddAudio:(NSString *)url title:(NSString *)title {
    [self.boardController addAudioElement:url withTitle:title];
}

- (void)onAddVideo {
    [self openPopWebview:kAddVideoFileUrl];
}

- (void)onAddWatermark {
    [self openPopWebview:kAddWatermarkUrl];
}

- (void)onExportInLocalMode {
    self.dataExported = [self.boardController exportInLocalMode];
    [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"DataSavedLocallyTryImport", nil)];
}

- (void)onImportInLocalMode {
    [self.boardController setDataSyncEnable:false];
    [self.boardController importInLocalMode:self.dataExported];
    [self.boardController setDataSyncEnable:true];
}

- (void)onExportInLocalModeWithFilter {
    self.dataExported = [self.boardController exportInLocalModeWithFilter:@"{\"include\":{\"types\":[801]}}"];
    [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"DataSavedLocallyTryImport", nil)];
}

- (void)onImportInLocalModeWithFilter {
    [self.boardController importInLocalMode:self.dataExported withFilter:@"{\"include\":{\"types\":[801]}}"];
}

- (void)onShowElements {
    [self.boardController setElementsDisplay:@[@(801)] ids:@[] visible:true];
}

- (void)onHideElements {
    [self.boardController setElementsDisplay:@[@(801)] ids:@[] visible:false];
}

- (void)onSetPermission {
    [self openPopWebview:kPermissionUrl];
    [self.popWebview sendToH5:@"setPermission" params:self.permissionDic];
}

- (void)onUndo
{
    [self.boardController undo];
}

- (void)onRedo
{
    [self.boardController redo];
}
- (void)onClearBackground
{
    [self.boardController setBackgroundImage:@"" mode:0];
}
- (void)onClear
{
    [self.boardController clear];
}
- (void)onClearDraw
{
    [self.boardController clearDraws];
}

- (void)onReset
{
    [self.boardController reset];
    [self closePopWebview];
}

- (void)onSetBackgroundImage:(NSString *)path
{
    [self.boardController setBackgroundImage:path mode:TEDU_BOARD_IMAGE_FIT_MODE_CENTER];
}

- (void)onAddBoard:(NSInteger)index
{
    [self.boardController addBoard:nil model:TEDU_BOARD_IMAGE_FIT_MODE_CENTER type:TEDU_BOARD_BACKGROUND_IMAGE needSwitch:YES index:index];
}

- (void)onDeleteBoard:(NSString *)boardId
{
    [self.boardController deleteBoard:boardId];
}

- (void)onGotoBoard:(NSString *)boardId resetStep:(BOOL)resetStep
{
    [self.boardController gotoBoard:boardId resetStep:resetStep];
}

- (void)onBoardScaleChanged:(int)scale
{
    [self.boardController setBoardScale:scale];
}

- (void)onBoardContentFitMode:(int)mode
{
    [self.boardController setBoardContentFitMode:(TEduBoardContentFitMode)mode];
}

- (int)getBoardContentFitMode
{
    return (int)[self.boardController getBoardContentFitMode];
}

- (void)onBoardRatioChanged:(NSString *)ratio
{
    [self.boardController setBoardRatio:ratio];
}

- (NSString *)getBoardRatio
{
    return [self.boardController getBoardRatio];
}

- (NSArray<NSString *> *)getBoardList
{
    return [self.boardController getBoardList];
}

- (NSString *)getCurrentBoard
{
    return [self.boardController getCurrentBoard];
}

- (void)onPreStep
{
    [self.boardController prevStep];
}
- (void)onNextStep
{
    [self.boardController nextStep];
}

- (void)onPreBoard:(BOOL)resetStep
{
    [self.boardController preBoard:resetStep];
}
- (void)onNextBoard:(BOOL)resetStep
{
    [self.boardController nextBoard:resetStep];
}

- (void)onSwitchFile:(NSString *)fileId
{
    [self.boardController switchFile:fileId];
}

- (void)onDownGrade:(NSString *)fid {
    [self.boardController setDownGrade:fid slideIndex:0 enable:YES];
}

- (void)onUpGrade:(NSString *)fid {
    [self.boardController setDownGrade:fid slideIndex:0 enable:NO];
}

- (void)onDeleteFile:(NSString *)fileId
{
    if ([[fileId uppercaseString] isEqualToString:@"#DEFAULT"]) {
        [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"CannotDeleteDefaultWhiteboard", nil)];
        return;
    }
    [self.boardController deleteFile:fileId];
}

- (void)onTEBBoardCursorPosition:(CGPoint)position {
    NSLog(@"onTEBBoardCursorPosition, x = %.1f, y= %.1f......", position.x, position.y);
}

- (void)onSetOwnerNickNameVisible:(BOOL)state {
    [self.boardController setOwnerNickNameVisible:state];
}

- (NSArray<NSString *> *)getFileList
{
    NSArray<TEduBoardFileInfo *> *files = [self.boardController getFileInfoList];
    NSMutableArray *names = [NSMutableArray array];
    for (TEduBoardFileInfo *file in files) {
        [names addObject:file.fileId];
    }
    return names;
}
- (NSString *)getCurrentFile
{
    return [self.boardController getCurrentFile];
}

- (void)onAddMathBoard {
    TEduBoardElementMathBoard *mathboard = [[TEduBoardElementMathBoard alloc] init];
    mathboard.axisColor = UIColor.orangeColor;
    [self.boardController addElementWithBoard:mathboard options:nil];
}

- (void)onSetMathGraphType:(NSInteger)type {
    [self.boardController setMathGraphType:type mouseTool:YES];
}

- (void)onAddTranscodeFile {
    [self openPopWebview:kAddTransCodeFileUrl];
}

- (NSArray<NSString *>*)getMediaList:(BOOL)isVideo {
    NSArray<TEduBoardFileInfo *> *infoList = [self.boardController getFileInfoList];
    NSMutableArray *result = [NSMutableArray array];
    for (TEduBoardFileInfo *info in infoList) {
        NSArray *list = isVideo ? info.mediaInfo.videoIDList : info.mediaInfo.audioIDList;
        if(list && list.count > 0) {
            [result addObjectsFromArray:list];
        }
    }
    return result;
}

- (void)onPlayPPTVideo {
    [self.boardController playH5PPTVideo:[self getMediaList:YES]];
}

- (void)onPausePPTVideo {
    [self.boardController pauseH5PPTVideo:[self getMediaList:YES]];
}

- (void)onPlayPPTAudio {
    [self.boardController playH5PPTAudio:[self getMediaList:NO]];
}

- (void)onPausePPTAudio {
    [self.boardController pauseH5PPTAudio:[self getMediaList:NO]];
}

- (void)onTEBBoardH5pptDownGrade:(NSString *)filedId slideIndex:(NSInteger)slideIndex {
    [self.boardController setDownGrade:filedId slideIndex:slideIndex enable:YES];
    [self addMsgInChatView:[NSString stringWithFormat:@"PPT加载超时(fid=%@)，将进行降级渲染", filedId]];
}

- (void)onTEBH5PPTMediaStatusChanged:(NSString *)fileId
                             mediaId:(NSString *)mediaId
                              status:(TEduBoardH5PPTMediaStatus)status
                         currentTime:(double)currentTime {
    [self addMsgInChatView:[NSString stringWithFormat:@"H5PPTMediaStatusChanged, fileId = %@, mediaId = %@, status = %@, currentTime = %.1f",
                            fileId,
                            mediaId,
                            status == TEDU_BOARD_H5_PPT_MEDIA_STATUS_PLAY ? @"播放" : @"暂停",
                            currentTime]];
}
#pragma mark - keyboard

//当键盘出现或改变时调用
- (void)keyboardWillShow:(NSNotification *)note {
//    CGRect frame = self.view.frame;
//    float height = self.view.frame.size.height > 680 ? -180 : -120;
//    frame.origin.y = height;
//    CGFloat duration = [note.userInfo[UIKeyboardAnimationDurationUserInfoKey] floatValue];
//    __weak typeof(self) ws = self;
//    [UIView animateWithDuration:duration animations:^{
//        ws.view.frame = frame;
//    }];
    UIColor *color = [self.boardController getBackgroundColor];
    if (color) {
        CGFloat r,g,b,a;
        [color getRed:&r green:&g blue:&b alpha:&a];
        if(a >= 1.0) {
            self.imgView.hidden = YES;
        }
    }
}

//当键盘消失时调用
- (void)keyboardWillHide:(NSNotification *)note {

//    double duration = [note.userInfo[UIKeyboardAnimationDurationUserInfoKey] doubleValue];
//    CGRect frame = self.view.frame;
//    frame.origin.y = 0;
//    __weak typeof(self) ws = self;
//    [UIView animateWithDuration:duration animations:^{
//        ws.view.frame = frame;
//    }];
    UIColor *color = [self.boardController getBackgroundColor];
    if (color) {
        CGFloat r,g,b,a;
        [color getRed:&r green:&g blue:&b alpha:&a];
        if(a >= 1.0) {
            self.imgView.hidden = NO;
        }
    }
}

#pragma mark - text field delegate

- (BOOL)textFieldShouldReturn:(UITextField *)textField {
    [textField resignFirstResponder];
    return YES;
}

#pragma mark - Custom Action

- (UIColor *)randomColor{
    CGFloat hue = ( arc4random() % 256 / 256.0 );
    CGFloat saturation = ( arc4random() % 128 / 256.0 ) + 0.5;
    CGFloat brightness = ( arc4random() % 128 / 256.0 ) + 0.5;
    return [UIColor colorWithHue:hue saturation:saturation brightness:brightness alpha:1];
}


#pragma mark - IMManagerListener

- (void)onRecvGroupTextMessage:(NSString *)text groupId:(NSString *)groupId fromUserId:(NSString *)fromUserId
{
    // 接收到房间内其他成员发出的文本消息，将消息按"[发送者] 消息内容"格式展示在界面上
//    NSString *msgInfo = [NSString stringWithFormat:@"[%@] %@",fromUserId, text];
//    self.chatView.text = [NSString stringWithFormat:@"%@\n%@",self.chatView.text, msgInfo];
//    [self.chatView scrollRangeToVisible:NSMakeRange(self.chatView.text.length, 1)];
}

// 接收到个人文本消息
- (void)onRecvCTCTextMessage:(NSString *)text fromUserId:(NSString *)fromUserId {
//    NSString *msgInfo = [NSString stringWithFormat:@"[%@]（私聊）：%@",fromUserId, text];
//    self.chatView.text = [NSString stringWithFormat:@"%@\n%@",self.chatView.text, msgInfo];
//    [self.chatView scrollRangeToVisible:NSMakeRange(self.chatView.text.length, 1)];
}

- (void)addMsgInChatView:(NSString *)msg {
    self.chatView.text = [NSString stringWithFormat:@"%@\n%@", self.chatView.text, msg];
    [self.chatView scrollRangeToVisible:NSMakeRange(self.chatView.text.length, 1)];
}

@end
