//
//  MenuTableViewController.m
//  TICDemo
//
//  Created by kennethmiao on 2019/4/25.
//  Copyright © 2019年 Tencent. All rights reserved.
//

#import "MenuTableViewController.h"
#import "PickSheetView.h"
#import "TableSheetView.h"
#import "BoardManager.h"
#import <MobileCoreServices/MobileCoreServices.h>
#if TARGET_OS_IPHONE
#import <TEduBoard/TEduBoard.h>
#else
#import <TEduBoard_Mac/TEduBoard.h>
#endif

@interface MenuTableViewController ()
@property (strong, nonatomic) UITableView *subTableView;
@property (strong, nonatomic) NSMutableArray *subMenus;
@property (strong, nonatomic) PickSheetView *pickView;
@property (strong, nonatomic) TableSheetView *tableSheet;
@property (strong, nonatomic) UIColor *brushColor;
@property (strong, nonatomic) UIColor *textColor;
@property (strong, nonatomic) UIColor *fluorescentColor;
@property (strong, nonatomic) UIColor *backColor;
@property (strong, nonatomic) UIColor *globalackColor;
@property (assign, nonatomic) NSInteger selectToolIndex;
@property (assign, nonatomic) NSInteger selectGraphStyle;
@property (assign, nonatomic) NSInteger selectMathToolIndex;
@property (assign, nonatomic) NSInteger textStyleIndex;
@property (assign, nonatomic) NSInteger textFamilyIndex;
@property (weak, nonatomic) IBOutlet UIButton *undoButton;
@property (weak, nonatomic) IBOutlet UIButton *redoButton;
@property (weak, nonatomic) IBOutlet UISwitch *preRestStepSwitch;
@property (weak, nonatomic) IBOutlet UISwitch *nextRestStepSwitch;
@property (weak, nonatomic) IBOutlet UISwitch *gotoRestStepSwitch;
@property (weak, nonatomic) IBOutlet UISwitch *magicSwitch;
@property (weak, nonatomic) IBOutlet UISegmentedControl *magicSegmented;
@property (weak, nonatomic) IBOutlet UISlider *textHeightSlider;
@property (weak, nonatomic) IBOutlet UISlider *eraserSlider;

@end

@implementation MenuTableViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.view.backgroundColor = [UIColor colorWithRed:0 green:0 blue:0 alpha:0.7];
    self.brushColor = [UIColor colorWithRed:1.0 green:0 blue:0 alpha:1.0];
    self.textColor = [UIColor colorWithRed:1.0 green:0 blue:0 alpha:1.0];
    self.backColor = [UIColor colorWithRed:1.0 green:1.0 blue:1.0 alpha:1.0];
    self.fluorescentColor = [UIColor colorWithRed:1.0 green:0 blue:0 alpha:0.5];
    self.globalackColor = [UIColor colorWithRed:1.0 green:1.0 blue:1.0 alpha:1.0];
    //    [self.magicSegmented setTitleTextAttributes:@{NSForegroundColorAttributeName:[UIColor whiteColor]}forState:UIControlStateSelected];
    [self.magicSegmented setTitleTextAttributes:@{NSForegroundColorAttributeName:[UIColor systemBlueColor]}forState:UIControlStateNormal];
}



- (void)setCanUndo:(BOOL)canUndo
{
    self.undoButton.enabled = canUndo;
}

- (void)setCanRedo:(BOOL)canRedo
{
    self.redoButton.enabled = canRedo;
}

#pragma mark - action

- (IBAction)onMagicPenChanged:(id)sender {
    if (self.delegate && [self.delegate respondsToSelector:@selector(onMagicPenChanged:)]) {
        BOOL state = self.magicSwitch.isOn;
        if(state) {
            NSInteger index = self.magicSegmented.selectedSegmentIndex + 1;
            [self.delegate onMagicPenChanged:index];
        }
        else {
            [self.delegate onMagicPenChanged:0];
        }
    }
}

- (IBAction)onMagicPenSegmentChanged:(id)sender {
    if (self.delegate && [self.delegate respondsToSelector:@selector(onMagicPenChanged:)]) {
        BOOL state = self.magicSwitch.isOn;
        if(state) {
            NSInteger index = self.magicSegmented.selectedSegmentIndex + 1;
            [self.delegate onMagicPenChanged:index];
        }
        else {
            [self.delegate onMagicPenChanged:0];
        }
    }
}

- (IBAction)onMultiTouchChanged:(id)sender {
    if (self.delegate && [self.delegate respondsToSelector:@selector(onMultiTouchChanged:)]) {
        BOOL state = ((UISwitch *)sender).isOn;
        [self.delegate onMultiTouchChanged:state];
    }
}

- (IBAction)onDisableTouchChanged:(id)sender {
    if (self.delegate && [self.delegate respondsToSelector:@selector(onDisableTouchChanged:)]) {
        BOOL state = ((UISwitch *)sender).isOn;
        [self.delegate onDisableTouchChanged:state];
    }
}

- (IBAction)onPiecewiseErasureChanged:(id)sender {
    if (self.delegate && [self.delegate respondsToSelector:@selector(onPiecewiseErasureChanged:)]) {
        BOOL state = ((UISwitch *)sender).isOn;
        [self.delegate onPiecewiseErasureChanged:state];
    }
}

- (IBAction)onSetOwnerNickNameVisible:(id)sender {
    if (self.delegate && [self.delegate respondsToSelector:@selector(onSetOwnerNickNameVisible:)]) {
        BOOL state = ((UISwitch *)sender).isOn;
        [self.delegate onSetOwnerNickNameVisible:state];
    }
}

- (IBAction)onDrawStateChanged:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onDrawStateChanged:)]){
        BOOL state = ((UISwitch *)sender).isOn;
        [self.delegate onDrawStateChanged:state];
    }
}

- (IBAction)onSyncDataChanged:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onSyncDataChanged:)]){
        BOOL state = ((UISwitch *)sender).isOn;
        [self.delegate onSyncDataChanged:state];
    }
}

- (IBAction)onAddElementAutoSelect:(id)sender {
    if (self.delegate && [self.delegate respondsToSelector:@selector(onAddElementAutoSelect:)]) {
        BOOL state = ((UISwitch *)sender).isOn;
        [self.delegate onAddElementAutoSelect:state];
    }
}

- (IBAction)onSelectToolType:(id)sender {
    NSMutableArray *array = [NSMutableArray array];
    [array addObject:NSLocalizedString(@"Mouse", nil)];
    [array addObject:NSLocalizedString(@"Pen", nil)];
    [array addObject:NSLocalizedString(@"Eraser", nil)];
    [array addObject:NSLocalizedString(@"LaserPen", nil)];
    [array addObject:NSLocalizedString(@"StraightLine", nil)];
    [array addObject:NSLocalizedString(@"HollowEllipse", nil)];
    [array addObject:NSLocalizedString(@"HollowRectangle", nil)];
    [array addObject:NSLocalizedString(@"SolidEllipse", nil)];
    [array addObject:NSLocalizedString(@"SolidRectangle", nil)];
    [array addObject:NSLocalizedString(@"PointSelectionTool", nil)];
    //    [array addObject:@"框选工具"];
    [array addObject:NSLocalizedString(@"TextTool", nil)];
    [array addObject:NSLocalizedString(@"ZoomMove", nil)];
    [array addObject:NSLocalizedString(@"HollowSquare", nil)];
    [array addObject:NSLocalizedString(@"SolidSquare", nil)];
    [array addObject:NSLocalizedString(@"HollowCircle", nil)];
    [array addObject:NSLocalizedString(@"SolidCircle", nil)];
    [array addObject:NSLocalizedString(@"CustomShape", nil)];
    
    //    [array addObject:@"圆弧"];
    [array addObject:NSLocalizedString(@"Highlighter", nil)];
    [array addObject:NSLocalizedString(@"RightAngleTriangle", nil)];
    [array addObject:NSLocalizedString(@"IsoscelesTriangle", nil)];
    [array addObject:NSLocalizedString(@"Parallelogram", nil)];
    [array addObject:NSLocalizedString(@"Cube", nil)];
    [array addObject:NSLocalizedString(@"Cylinder", nil)];
    [array addObject:NSLocalizedString(@"Cone", nil)];
    [array addObject:NSLocalizedString(@"CoordinateSystem", nil)];
    
    [self.tableSheet setSelectIndex:self.selectToolIndex];
    [self.tableSheet setData:array];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        ws.selectToolIndex = index;
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSelectToolType:)]){
            [ws.delegate onSelectToolType:(int)index];
        }
    };
    [self.view.superview addSubview:self.tableSheet];
}

- (IBAction)onSelectGraphStyle:(id)sender {
    NSMutableArray *array = [NSMutableArray array];
    [array addObject:NSLocalizedString(@"DashedLineNoArrow", nil)];
    [array addObject:NSLocalizedString(@"SolidLineEndPointSolidArrow", nil)];
    [array addObject:NSLocalizedString(@"DashedLineStartPointOrdinaryArrow", nil)];
    [array addObject:NSLocalizedString(@"SolidLineStartPointSolidArrowEndPointOrdinaryArrow", nil)];
    [array addObject:NSLocalizedString(@"SolidTriangle", nil)];
    [array addObject:NSLocalizedString(@"DashedHollowRectangle", nil)];
    [array addObject:NSLocalizedString(@"SolidIsoscelesTriangle", nil)];
    [array addObject:NSLocalizedString(@"SolidRightAngleTriangle", nil)];
    [array addObject:NSLocalizedString(@"SolidParallelogram", nil)];
    
    [self.tableSheet setSelectIndex:self.selectGraphStyle];
    [self.tableSheet setData:array];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        ws.selectGraphStyle = index;
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSelectToolType:)]){
            [ws.delegate onSelectGraphStyle:(int)index];
        }
    };
    [self.view.superview addSubview:self.tableSheet];
}
- (IBAction)onSelectMathToolType:(id)sender {
    NSMutableArray *array = [NSMutableArray array];
    [array addObject:NSLocalizedString(@"StraightRuler", nil)];
    [array addObject:NSLocalizedString(@"RightAngleTriangle", nil)];
    [array addObject:NSLocalizedString(@"IsoscelesRightAngleTriangle", nil)];
    [array addObject:NSLocalizedString(@"Protractor", nil)];
    [array addObject:NSLocalizedString(@"Compass", nil)];
    
    [self.tableSheet setSelectIndex:self.selectMathToolIndex];
    [self.tableSheet setData:array];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        ws.selectMathToolIndex = index;
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSelectMathToolType:)]){
            [ws.delegate onSelectMathToolType:(int)index + 1];
        }
    };
    [self.view.superview addSubview:self.tableSheet];
}

- (IBAction)onSelectCustomGraph:(id)sender {
    NSMutableArray *array = [NSMutableArray array];
    [array addObject:NSLocalizedString(@"Triangle", nil)];
    [array addObject:NSLocalizedString(@"Heart", nil)];
    [array addObject:NSLocalizedString(@"Pentagram", nil)];
    
    NSMutableArray *values = [NSMutableArray array];;
    [values addObject:@"https://demo.qcloudtiw.com/resource/triangle.svg"];
    [values addObject:@"https://demo.qcloudtiw.com/resource/heart.svg"];
    [values addObject:@"https://demo.qcloudtiw.com/resource/star.svg"];
    
    [self.tableSheet setData:array];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSelectCustomGraph:)]){
            [ws.delegate onSelectCustomGraph:[values objectAtIndex:index]];
        }
    };
    [self.view.superview addSubview:self.tableSheet];
}

- (IBAction)onSelectBrushColor:(id)sender {
    [self.pickView setColor:self.brushColor];
    __weak typeof(self) ws = self;
    self.pickView.block = ^(UIColor *color){
        ws.brushColor = color;
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSelectBrushColor:)]){
            [ws.delegate onSelectBrushColor:color];
        }
    };
    [self.view.superview addSubview:self.pickView];
}

- (IBAction)onSelectBackgroundColor:(id)sender {
    [self.pickView setColor:self.backColor];
    __weak typeof(self) ws = self;
    self.pickView.block = ^(UIColor *color){
        ws.backColor = color;
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSelectBackgroundColor:)]){
            [ws.delegate onSelectBackgroundColor:color];
        }
    };
    [self.view.superview addSubview:self.pickView];
}

- (IBAction)onSelectGlobalBackgroundColor:(id)sender {
    [self.pickView setColor:self.globalackColor];
    __weak typeof(self) ws = self;
    self.pickView.block = ^(UIColor *color){
        ws.globalackColor = color;
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSelectBackgroundColor:)]){
            [ws.delegate onSelectGlobalBackgroundColor:color];
        }
    };
    [self.view.superview addSubview:self.pickView];
}

- (IBAction)onBrushThinChanged:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onBrushThinChanged:)]){
        float value = ((UISlider *)sender).value;
        [self.delegate onBrushThinChanged:value];
    }
}


- (IBAction)onSelectTextColor:(id)sender {
    [self.pickView setColor:self.textColor];
    __weak typeof(self) ws = self;
    self.pickView.block = ^(UIColor *color){
        ws.textColor = color;
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSelectTextColor:)]){
            [ws.delegate onSelectTextColor:color];
        }
    };
    [self.view.superview addSubview:self.pickView];
}

- (IBAction)onSelectFluorescentColor:(id)sender {
    self.fluorescentColor = [[BoardManager sharedInstance].boardController getHighlighterColor];
    [self.pickView setColor:self.fluorescentColor];
    __weak typeof(self) ws = self;
    self.pickView.block = ^(UIColor *color){
        ws.fluorescentColor = color;
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSelectFluorescentColor:)]){
            [ws.delegate onSelectFluorescentColor:color];
        }
    };
    [self.view.superview addSubview:self.pickView];
}

- (IBAction)onTextSizeChanged:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onTextSizeChanged:)]){
        float value = ((UISlider *)sender).value;
        [self.delegate onTextSizeChanged:value];
    }
}

- (IBAction)onEraserSizeChanged:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onEraserSizeChanged:)]){
        float value = ((UISlider *)sender).value;
        [self.delegate onEraserSizeChanged:value];
    }
}

- (void)setTextHeight:(float)value {
    [self.textHeightSlider setValue:value];
}

- (void)setEraserSize:(float)value {
    [self.eraserSlider setValue:value];
}

- (IBAction)onTextHeightChanged:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onTextHeightChanged:)]){
        float value = ((UISlider *)sender).value;
        [self.delegate onTextHeightChanged:value];
    }
}


- (IBAction)onSetBackgroundH5:(id)sender {
    NSMutableArray *array = [NSMutableArray array];
    [array addObject:@"https://cloud.tencent.com/product/tiw"];
    
    [self.tableSheet setData:array];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSetBackgroundH5:)]){
            [ws.delegate onSetBackgroundH5:array[index]];
        }
    };
    [self.view.superview addSubview:self.tableSheet];
}

- (IBAction)onSetTextStyle:(id)sender {
    NSMutableArray *array = [NSMutableArray array];
    [array addObject:NSLocalizedString(@"RegularStyle", nil)];
    [array addObject:NSLocalizedString(@"BoldStyle", nil)];
    [array addObject:NSLocalizedString(@"ItalicStyle", nil)];
    [array addObject:NSLocalizedString(@"BoldItalicStyle", nil)];
    
    [self.tableSheet setSelectIndex:self.textStyleIndex];
    [self.tableSheet setData:array];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        ws.textStyleIndex = index;
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSetTextStyle:)]){
            [ws.delegate onSetTextStyle:(int)index];
        }
    };
    [self.view.superview addSubview:self.tableSheet];
}

- (IBAction)onSetTextFamily:(id)sender {
    NSArray *array =[UIFont familyNames];
    [self.tableSheet setSelectIndex:self.textFamilyIndex];
    [self.tableSheet setData:array];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        ws.textFamilyIndex = index;
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSetTextFamily:)]){
            [ws.delegate onSetTextFamily:array[index]];
        }
    };
    [self.view.superview addSubview:self.tableSheet];
}




- (IBAction)onUndo:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onUndo)]){
        [self.delegate onUndo];
    }
}

- (IBAction)onRedo:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onRedo)]){
        [self.delegate onRedo];
    }
}
- (IBAction)onClearBackground:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onClearBackground)]){
        [self.delegate onClearBackground];
    }
}
- (IBAction)onClear:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onClear)]){
        [self.delegate onClear];
    }
}
- (IBAction)onClearDraw:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onClearDraw)]){
        [self.delegate onClearDraw];
    }
}

- (IBAction)onReset:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onReset)]){
        [self.delegate onReset];
    }
}

- (IBAction)onSetBackgroundImage:(id)sender {
    NSMutableArray *array = [NSMutableArray array];
    
    [array addObject:@"https://demo-1259648581.cos.ap-nanjing.myqcloud.com/image/3e1ac1a1929b7561a9299c544cffae12.jpeg"];
    [array addObject:@"https://demo-1259648581.cos.ap-nanjing.myqcloud.com/image/9a2da4ee6a631ce06ca6177a250a6fc5.jpg"];
    [array addObject:@"https://demo-1259648581.cos.ap-nanjing.myqcloud.com/image/13256d24640f79202c90950cf5e653c6.jpeg"];
    [array addObject:@"https://demo-1259648581.cos.ap-nanjing.myqcloud.com/image/3d2978eb75aaed3a85ea693bd63349a4.jpeg"];
    
    [self.tableSheet setData:array];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSetBackgroundImage:)]){
            NSString *url = [array objectAtIndex:index];
            [ws.delegate onSetBackgroundImage:url];
        }
    };
    [self.view.superview addSubview:self.tableSheet];
}

- (IBAction)onAddBoard:(id)sender {
    NSArray *boards = [self.delegate getFileList];
    NSMutableArray<NSString *> *indexList = [NSMutableArray array];
    for(int i = 0; i <= boards.count; i++) {
        [indexList addObject:[NSString stringWithFormat:@"插入在第%d页", i]];
    }
    [self.tableSheet setData:indexList];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onAddBoard:)]){
            [ws.delegate onAddBoard:index];
        }
    };
    [self.view.superview addSubview:self.tableSheet];
}

- (IBAction)onDeleteBoard:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(getBoardList)]
       && [self.delegate respondsToSelector:@selector(getCurrentBoard)]){
        NSArray *boards = [self.delegate getBoardList];
        NSString *curBoard = [self.delegate getCurrentBoard];
        NSInteger curIndex = [boards indexOfObject:curBoard];
        [self.tableSheet setSelectIndex:curIndex];
        [self.tableSheet setData:boards];
        __weak typeof(self) ws = self;
        self.tableSheet.block = ^(NSInteger index){
            if(ws.delegate && [ws.delegate respondsToSelector:@selector(onDeleteBoard:)]){
                NSString *delBoard = [boards objectAtIndex:index];
                [ws.delegate onDeleteBoard:delBoard];
            }
        };
        [self.view.superview addSubview:self.tableSheet];
    }
    
}

- (IBAction)onGotoBoard:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(getBoardList)]
       && [self.delegate respondsToSelector:@selector(getCurrentBoard)]){
        
        BOOL state = _gotoRestStepSwitch.isOn;
        
        NSArray *boards = [self.delegate getBoardList];
        NSString *curBoard = [self.delegate getCurrentBoard];
        NSInteger curIndex = [boards indexOfObject:curBoard];
        [self.tableSheet setSelectIndex:curIndex];
        [self.tableSheet setData:boards];
        __weak typeof(self) ws = self;
        self.tableSheet.block = ^(NSInteger index){
            if(ws.delegate && [ws.delegate respondsToSelector:@selector(onGotoBoard:resetStep:)]){
                NSString *gotoBoard = [boards objectAtIndex:index];
                [ws.delegate onGotoBoard:gotoBoard resetStep:state];
            }
        };
        [self.view.superview addSubview:self.tableSheet];
    }
}
- (IBAction)onBoardScaleChanged:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onBoardScaleChanged:)]){
        int value = ((UISlider *)sender).value;
        [self.delegate onBoardScaleChanged:value];
    }
}
- (IBAction)onBoardContentFitMode:(id)sender {
    NSMutableArray *array = [NSMutableArray array];
    [array addObject:NSLocalizedString(@"ContentWHLessOrEqualThanBoardWH", nil)];
    [array addObject:NSLocalizedString(@"BoardWHLessOrEqualThanContentWH", nil)];
    [array addObject:NSLocalizedString(@"BoardWHGreaterOrEqualThanContentWH", nil)];
    
    int curMode = 0;
    if(_delegate && [_delegate respondsToSelector:@selector(getBoardContentFitMode)]){
        curMode = [_delegate getBoardContentFitMode];
    }
    [self.tableSheet setSelectIndex:curMode];
    [self.tableSheet setData:array];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onBoardContentFitMode:)]){
            [ws.delegate onBoardContentFitMode:(int)index];
        }
    };
    [self.view.superview addSubview:self.tableSheet];
}

- (IBAction)onBoardRatioChanged:(id)sender {
    NSMutableArray *array = [NSMutableArray array];
    [array addObject:@"16:9"];
    [array addObject:@"4:3"];
    
    NSString *curRatio = @"16:9";
    if(_delegate && [_delegate respondsToSelector:@selector(getBoardRatio)]){
        curRatio = [_delegate getBoardRatio];
    }
    NSInteger curIndex = [array indexOfObject:curRatio];
    [self.tableSheet setSelectIndex:curIndex];
    [self.tableSheet setData:array];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        NSString *selectRatio = [array objectAtIndex:index];
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onBoardRatioChanged:)]){
            [ws.delegate onBoardRatioChanged:selectRatio];
        }
    };
    [self.view.superview addSubview:self.tableSheet];
}


- (IBAction)onPreBoard:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onPreBoard:)]){
        BOOL state = _preRestStepSwitch.isOn;
        [self.delegate onPreBoard:state];
    }
}
- (IBAction)onNextBoard:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onNextBoard:)]){
        BOOL state = _nextRestStepSwitch.isOn;
        [self.delegate onNextBoard:state];
    }
}

- (IBAction)onPreStep:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onPreStep)]){
        [self.delegate onPreStep];
    }
}
- (IBAction)onNextStep:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onNextStep)]){
        [self.delegate onNextStep];
    }
}

- (IBAction)onSnapshot:(id)sender {
    
    NSMutableArray *array = [NSMutableArray array];
    
    [array addObject:@"所见即所得模式"];
    [array addObject:@"全尺寸模式（请放大白板后体验）"];
    
    [self.tableSheet setData:array];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        BOOL full = index == 1;
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSnapshot:)]){
            [ws.delegate onSnapshot:full];
        }
    };
    [self.view.superview addSubview:self.tableSheet];
    
}

- (IBAction)onUploadFile:(id)sender {
    //    NSMutableArray *array = [NSMutableArray array];
    //    NSString *test1Path = [[NSBundle mainBundle] pathForResource:@"local_test1" ofType:@"pptx"];
    //    NSString *test2Path = [[NSBundle mainBundle] pathForResource:@"local_test2" ofType:@"pptx"];
    //    NSString *test3Path = [[NSBundle mainBundle] pathForResource:@"小程序插件统计报表" ofType:@"pdf"];
    //
    //    [array addObject:test1Path];
    //    [array addObject:test2Path];
    //    [array addObject:test3Path];
    //    [array addObject:@"http://e4fb-edu-1400127140-1257240443.cos.ap-shanghai.myqcloud.com/TIC/WEB/1557368577909_3.%E6%88%AA%E4%B8%80%E4%B8%AA%E5%87%A0%E4%BD%95%E4%BD%93.ppt"];
    //
    //    [self.tableSheet setData:array];
    //    __weak typeof(self) ws = self;
    //    self.tableSheet.block = ^(NSInteger index){
    //        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onUploadFile:)]){
    //            [ws.delegate onUploadFile:array[index]];
    //        }
    //    };
    //    [self.view.superview addSubview:self.tableSheet];
}

- (IBAction)onSwitchFile:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(getFileList)]
       && [self.delegate respondsToSelector:@selector(getCurrentFile)]){
        NSArray *files = [self.delegate getFileList];
        NSString *curFile = [self.delegate getCurrentFile];
        NSInteger curIndex = [files indexOfObject:curFile];
        [self.tableSheet setSelectIndex:curIndex];
        [self.tableSheet setData:files];
        __weak typeof(self) ws = self;
        self.tableSheet.block = ^(NSInteger index){
            if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSwitchFile:)]){
                NSString *switchFile = [files objectAtIndex:index];
                [ws.delegate onSwitchFile:switchFile];
            }
        };
        [self.view.superview addSubview:self.tableSheet];
    }
}
- (IBAction)onDeleteFile:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(getFileList)]
       && [self.delegate respondsToSelector:@selector(getCurrentFile)]){
        NSArray *files = [self.delegate getFileList];
        NSString *curFile = [self.delegate getCurrentFile];
        NSInteger curIndex = [files indexOfObject:curFile];
        [self.tableSheet setSelectIndex:curIndex];
        [self.tableSheet setData:files];
        __weak typeof(self) ws = self;
        self.tableSheet.block = ^(NSInteger index){
            if(ws.delegate && [ws.delegate respondsToSelector:@selector(onDeleteFile:)]){
                NSString *switchFile = [files objectAtIndex:index];
                [ws.delegate onDeleteFile:switchFile];
            }
        };
        [self.view.superview addSubview:self.tableSheet];
    }
}

- (IBAction)onAddH5File:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onAddH5File:)]){
        [self.delegate onAddH5File:0];
    }
}


- (IBAction)onAddTranscodeFile:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onAddTranscodeFile)]){
        [self.delegate onAddTranscodeFile];
    }
}

- (IBAction)onPlayPPTVideo:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onPlayPPTVideo)]){
        [self.delegate onPlayPPTVideo];
    }
}

- (IBAction)onPausePPTVideo:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onPausePPTVideo)]){
        [self.delegate onPausePPTVideo];
    }
}

- (IBAction)onPlayPPTAudio:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onPlayPPTAudio)]){
        [self.delegate onPlayPPTAudio];
    }
}

- (IBAction)onPausePPTAudio:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onPausePPTAudio)]){
        [self.delegate onPausePPTAudio];
    }
}

- (IBAction)onAddAudio:(id)sender {
    NSMutableArray *array = [NSMutableArray array];
    [array addObject:NSLocalizedString(@"Audio1", nil)];
    [array addObject:NSLocalizedString(@"Audio2", nil)];
    
    [self.tableSheet setData:array];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onAddAudio:title:)]){
            if(index == 0) {
                [ws.delegate onAddAudio:@"https://test-1259648581.cos.ap-shanghai.myqcloud.com/media/xxx.mp3" title:NSLocalizedString(@"AudioTitle1", nil)];
            }
            else {
                [ws.delegate onAddAudio:@"https://test-1259648581.cos.ap-shanghai.myqcloud.com/%E6%A2%81%E9%9D%99%E8%8C%B9%20-%20%E6%83%85%E6%AD%8C.mp3" title:NSLocalizedString(@"AudioTitle2", nil)];
            }
        }
    };
    [self.view.superview addSubview:self.tableSheet];
}
- (IBAction)onAddVideo:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onAddVideo)]) {
        [self.delegate onAddVideo];
    }
}

- (IBAction)onAddWatermark:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onAddWatermark)]) {
        [self.delegate onAddWatermark];
    }
}

- (IBAction)onExportInLocalMode:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onExportInLocalMode)]) {
        [self.delegate onExportInLocalMode];
    }
}

- (IBAction)onImportInLocalMode:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onImportInLocalMode)]) {
        [self.delegate onImportInLocalMode];
    }
}


- (IBAction)onSetPermission:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onSetPermission)]) {
        [self.delegate onSetPermission];
    }
}
- (IBAction)onExportInLocalModeWithFilter:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onExportInLocalModeWithFilter)]) {
        [self.delegate onExportInLocalModeWithFilter];
    }
}

- (IBAction)onImportInLocalModeWithFilter:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onImportInLocalModeWithFilter)]) {
        [self.delegate onImportInLocalModeWithFilter];
    }
}
- (IBAction)onHideElements:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onHideElements)]) {
        [self.delegate onHideElements];
    }
}
- (IBAction)onShowElements:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onShowElements)]) {
        [self.delegate onShowElements];
    }
}

#pragma mark - document
- (void)documentPicker:(UIDocumentPickerViewController *)controller didPickDocumentsAtURLs:(NSArray <NSURL *>*)urls {
//    NSURL *url = urls.firstObject;
//    NSString *path = [[url absoluteString] stringByReplacingPercentEscapesUsingEncoding:NSUTF8StringEncoding];
//    [url startAccessingSecurityScopedResource];
//    NSFileCoordinator *coordinator = [[NSFileCoordinator alloc] init];
//    NSError *error;
//    __weak typeof(self) ws = self;
//    [coordinator coordinateReadingItemAtURL:url options:0 error:&error byAccessor:^(NSURL *newURL) {
//        NSData *fileData = [NSData dataWithContentsOfURL:url];
//        NSString *fileName = [url lastPathComponent];
//        NSString *filePath = [[NSHomeDirectory() stringByAppendingString:@"/Library/Caches/"] stringByAppendingString:fileName];
//        [[NSFileManager defaultManager] createFileAtPath:filePath contents:fileData attributes:nil];
//        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onUploadFile:)]){
//            [ws.delegate onUploadFile:filePath];
//        }
//    }];
//    [url stopAccessingSecurityScopedResource];
}

#pragma mark - photo
- (void)imagePickerController:(UIImagePickerController *)picker didFinishPickingMediaWithInfo:(NSDictionary<NSString *,id> *)info
{
    NSString *mediaType = [info objectForKey:UIImagePickerControllerMediaType];
    if([mediaType isEqualToString:(NSString *)kUTTypeImage]){
        UIImage *image = [info objectForKey:UIImagePickerControllerOriginalImage];
        UIImageOrientation imageOrientation=  image.imageOrientation;
        UIImage *scaledImage = image;
        if (imageOrientation != UIImageOrientationUp) {
            UIGraphicsBeginImageContext(image.size);
            [image drawInRect:CGRectMake(0, 0, image.size.width, image.size.height)];
            scaledImage = UIGraphicsGetImageFromCurrentImageContext();
            UIGraphicsEndImageContext();
        }
        if (scaledImage) {
            CGFloat maxWidthOrHeight = 1000;
            CGFloat scaleFactor = MAX(scaledImage.size.width / maxWidthOrHeight, scaledImage.size.height / maxWidthOrHeight);

            if (scaleFactor > 1) {
                CGFloat newWidth = scaledImage.size.width / scaleFactor;
                CGFloat newHeight = scaledImage.size.height / scaleFactor;

                UIGraphicsBeginImageContext(CGSizeMake(newWidth, newHeight));
                [scaledImage drawInRect:CGRectMake(0, 0, newWidth, newHeight)];
                scaledImage = UIGraphicsGetImageFromCurrentImageContext();
                UIGraphicsEndImageContext();
            }
        }
        
        NSData *data = UIImageJPEGRepresentation(scaledImage, 0.8);
        NSString *name = [NSString stringWithFormat:@"%ld.jpg", (long)[[NSDate date] timeIntervalSince1970] * 1000];
        NSString *path = [[NSHomeDirectory() stringByAppendingString:@"/Library/Caches/"] stringByAppendingString:name];
        if([[NSFileManager defaultManager] createFileAtPath:path contents:data attributes:nil]){
            if(self.delegate && [self.delegate respondsToSelector:@selector(onSetBackgroundImage:)]){
                [self.delegate onSetBackgroundImage:path];
            }
        }
    }
    [picker dismissViewControllerAnimated:YES completion:nil];
}

#pragma  mark - lazy load
- (PickSheetView *)pickView
{
    if(!_pickView){
        _pickView = [[NSBundle mainBundle] loadNibNamed:@"PickSheetView" owner:self options:nil][0];
        CGSize size = [_pickView sizeThatFits:[UIScreen mainScreen].bounds.size];
        CGFloat bottom = 0;
        if (@available(iOS 11.0, *)) {
            bottom =  [[UIApplication sharedApplication] delegate].window.safeAreaInsets.bottom;
        }
        _pickView.frame = CGRectMake(0, self.view.superview.frame.size.height - size.height - bottom, self.view.superview.frame.size.width, size.height + bottom);
    }
    return _pickView;
}

- (TableSheetView *)tableSheet
{
    if(!_tableSheet){
        _tableSheet = [[NSBundle mainBundle] loadNibNamed:@"TableSheetView" owner:self options:nil][0];
        CGFloat height = self.view.superview.frame.size.height / 2;
        _tableSheet.frame = CGRectMake(0, self.view.superview.frame.size.height - height, self.view.superview.frame.size.width, height);
    }
    return _tableSheet;
}

- (IBAction)onAddMathBoard:(id)sender {
    if(self.delegate && [self.delegate respondsToSelector:@selector(onAddMathBoard)]){
        [self.delegate onAddMathBoard];
    }
}

- (IBAction)onSetMathGraphType:(id)sender {
//    TEduBoardMathGraphTypePOINT             =        1,       ///< 点
//    TEduBoardMathGraphTypeLINE              =        2,       ///< 直线
//    TEduBoardMathGraphTypeLINE_SEGMENT      =        3,       ///< 线段
//    TEduBoardMathGraphTypeRAY               =        4,       ///< 射线
//    TEduBoardMathGraphTypeCIRCLE            =        5,       ///< 圆
//    TEduBoardMathGraphTypeANGLE             =        6,       ///< 角
//    TEduBoardMathGraphTypePOLYGON           =        7,       ///< 多边形
//    TEduBoardMathGraphTypeVECTOR            =        8,       ///< 向量
//    TEduBoardMathGraphTypeELLIPSE           =        9,       ///< 椭圆
//    TEduBoardMathGraphTypeCUBE              =        101,       ///< 立方体
//    TEduBoardMathGraphTypeCYLINDER          =        102,       ///< 圆柱体
//    TEduBoardMathGraphTypeCIRCULAR_CONE     =        103,       ///< 圆锥体
    NSMutableArray *array = [NSMutableArray array];
    [array addObject:NSLocalizedString(@"Point", nil)];
    [array addObject:NSLocalizedString(@"StraightLine", nil)];
    [array addObject:NSLocalizedString(@"LineSegment", nil)];
    [array addObject:NSLocalizedString(@"Ray", nil)];
    [array addObject:NSLocalizedString(@"Circle", nil)];
    [array addObject:NSLocalizedString(@"Angle", nil)];
    [array addObject:NSLocalizedString(@"Polygon", nil)];
    [array addObject:NSLocalizedString(@"Vector", nil)];
    [array addObject:NSLocalizedString(@"Ellipse", nil)];
    [array addObject:NSLocalizedString(@"Cube", nil)];
    [array addObject:NSLocalizedString(@"Cylinder", nil)];
    [array addObject:NSLocalizedString(@"Cone", nil)];
    
    [self.tableSheet setSelectIndex:self.textStyleIndex];
    [self.tableSheet setData:array];
    __weak typeof(self) ws = self;
    self.tableSheet.block = ^(NSInteger index){
        NSInteger type = index + 1;
        if (index >= 9) {
            type = TEduBoardMathGraphTypeCube + (index - 9);
        }
        if(ws.delegate && [ws.delegate respondsToSelector:@selector(onSetMathGraphType:)]){
            [ws.delegate onSetMathGraphType: type];
        }
    };
    [self.view.superview addSubview:self.tableSheet];
    
   
}
@end
