//
//  WebViewDemo.m
//  TICDebugDemo
//
//  Created by 张小桥 on 2022/8/27.
//

#import "PopWebView.h"
#import <YYModel/YYModel.h>

static NSString *kJSMethod = @"sendMessageToNative";


@interface PopWebView ()

@property (nonatomic, assign) BOOL isFinshed;
@property (nonatomic, strong) NSMutableArray *jsArray;
@end


@implementation PopWebView

/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void)drawRect:(CGRect)rect {
    // Drawing code
}
*/

-(id)init {
    if (self = [super init]) {
        self.jsMethodArray = @[kJSMethod];
        
        WKWebView *webView = [[WKWebView alloc] initWithFrame:self.bounds];
        self.webView = webView;
        self.webView.navigationDelegate = self;
        [self.webView setBackgroundColor:[UIColor clearColor]];
        [self.webView setOpaque:NO];
        [self addSubview:webView];
        for (NSString *method in self.jsMethodArray) {
            [self injectMethod:method];
        }
        self.webView.frame = self.bounds;

    }
    return self;
}

- (void)loadUrl:(NSString *)url {
    NSMutableURLRequest *request = [[NSMutableURLRequest alloc] initWithURL:[NSURL URLWithString:url]];
    request.cachePolicy = NSURLRequestReloadIgnoringLocalCacheData;
    [self.webView loadRequest:request];
}

- (void)sendToH5:(NSString *)action params:(NSDictionary *)map {
//    evaluateJavaScript
    if (!map) {
        map = @{};
    }
    NSData *data = [NSJSONSerialization dataWithJSONObject:map options:NSJSONWritingPrettyPrinted error:nil];
    NSString *params = [[NSString alloc] initWithData:data encoding:NSUTF8StringEncoding];
//    params = [params stringByReplacingOccurrencesOfString:@" " withString:@""];
    params = [params stringByReplacingOccurrencesOfString:@"\r" withString:@""];
    params = [params stringByReplacingOccurrencesOfString:@"\n" withString:@""];

    NSString *jsstr = [NSString stringWithFormat:@"window.reciveMessageFromNative('%@', '%@')", action, params];
    if (self.isFinshed) {
        [self.webView evaluateJavaScript:jsstr completionHandler:^(id _Nullable response, NSError * _Nullable error) {
            NSLog(@"response = %@", response);
        }];
    }
    else {
        if (!self.jsArray) {
            self.jsArray = [NSMutableArray array];
        }
        [self.jsArray addObject:jsstr];
    }
}

- (void)unInit {
    for (NSString *method in self.jsMethodArray) {
        [self.webView.configuration.userContentController removeScriptMessageHandlerForName:method];
    }
    [self.webView removeFromSuperview];
}

- (void)layoutSubviews {
    [super layoutSubviews];
    self.webView.frame = self.bounds;
}

- (void)injectMethod:(NSString *)method{
    [self.webView.configuration.userContentController addScriptMessageHandler:self name:method];
    NSString *printContent = [NSString stringWithFormat:@"function %@(param) { window.webkit.messageHandlers.%@.postMessage(param);}", method, method];
    WKUserScript *userScript = [[WKUserScript alloc] initWithSource:printContent injectionTime:WKUserScriptInjectionTimeAtDocumentEnd forMainFrameOnly:YES];
    [self.webView.configuration.userContentController addUserScript:userScript];
}

- (void)userContentController:(nonnull WKUserContentController *)userContentController didReceiveScriptMessage:(nonnull WKScriptMessage *)message {
    if ([message.name isEqualToString:kJSMethod]) {
        id msgBody = message.body;
        NSDictionary *msgDic = nil;
        if ([msgBody isKindOfClass:[NSString class]]) {
            NSData *jsonData = [(NSString *)msgBody dataUsingEncoding: NSUTF8StringEncoding];
            msgDic = [NSJSONSerialization JSONObjectWithData:jsonData options:kNilOptions error:NULL];;
        } else if([msgBody isKindOfClass:[NSDictionary class]]) {
            msgDic = msgBody;
        }
        if (msgDic && [msgDic objectForKey:@"action"] && self.delegate && [self.delegate respondsToSelector:@selector(reciverH5Msg:data:)]) {
            [self.delegate reciverH5Msg:[msgDic objectForKey:@"action"] data:msgDic];
        }
        else {
            NSLog(NSLocalizedString(@"ParameterError", nil));
        }
    }
}

// 页面加载完成之后调用
- (void)webView:(WKWebView *)webView didFinishNavigation:(WKNavigation *)navigation {
    self.isFinshed = YES;
    dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(1 *NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
        for (NSString *jsstr in self.jsArray) {
            
            [self.webView evaluateJavaScript:jsstr completionHandler:^(id _Nullable response, NSError * _Nullable error) {
                NSLog(@"response = %@", response);
            }];
        }
    });
    
}
@end
