#import "ViewController.h"
#import "ClassroomJoinViewController.h"
#import "JMLoadingHUD.h"
#import "JMToast.h"
#import "IMManager.h"
#import "TICDemoConst.h"

#if TARGET_OS_IPHONE
#import <TEduBoard/TEduBoard.h>
#else
#import <TEduBoard_Mac/TEduBoard.h>
#endif

@interface ViewController () <UIPickerViewDelegate, UIPickerViewDataSource>
@property (weak, nonatomic) IBOutlet UIPickerView *userPickView;
@property (weak, nonatomic) IBOutlet UILabel *imsdkVerLabel;
@property (weak, nonatomic) IBOutlet UILabel *boardVerLabel;

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.title = @"TICDemo";
    
    self.imsdkVerLabel.text = [NSString stringWithFormat:@"IMSDK: %@", [[V2TIMManager sharedInstance] getVersion]];
    self.boardVerLabel.text = [NSString stringWithFormat:@"TEduBoard: %@", [TEduBoardController getVersion]];
    
    NSString *userid = [[NSUserDefaults standardUserDefaults] objectForKey:kLastLoginUserId];
    if (userid.length > 0) {
        NSArray *array = [userid componentsSeparatedByString:@"_"];
        NSInteger index = array.count >= 3 ? [array[2] intValue] : 0;
        if (index >=0 && index < kUserCount) {
            [_userPickView selectRow:index inComponent:0 animated:NO];
        }
    }
}

- (UIInterfaceOrientationMask)supportedInterfaceOrientations
{
    return UIInterfaceOrientationMaskPortrait;
}

- (IBAction)onLogin:(UIButton *)button {
    NSInteger index = [_userPickView selectedRowInComponent:0];
    NSString *userId = [NSString stringWithFormat:@"tiw_ios_%ld", index + 1];
//    NSString *userSig = [TICConfig shareInstance].userSigs[index];
    [JMLoadingHUD setTitle:NSLocalizedString(@"LoggingIn", nil)];
    [JMLoadingHUD show];
    
    __weak typeof(self) ws = self;
    dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_HIGH, 0), ^{
        NSString *userSig = [ViewController getUsersig:userId];
        // IM登录
        [[IMManager sharedInstance] login:userId userSig:userSig callback:^(int code, NSString * _Nullable desc) {
            if (code == 0) {
                [JMLoadingHUD hide];
                [[JMToast sharedToast] showDialogWithMsg:NSLocalizedString(@"LoginSuccessful", nil)];
                UIStoryboard *story = [UIStoryboard storyboardWithName:@"Main" bundle:[NSBundle mainBundle]];
                ClassroomJoinViewController *join = [story instantiateViewControllerWithIdentifier:@"ClassroomJoinViewController"];
                join.userId = userId;
                join.userSig = userSig;
                [[NSUserDefaults standardUserDefaults] setObject:userId forKey:kLastLoginUserId];
                [[NSUserDefaults standardUserDefaults] synchronize];
                [ws.navigationController pushViewController:join animated:YES];
            }
            else {
                [JMLoadingHUD hide];
                [[JMToast sharedToast] showDialogWithMsg:[NSString stringWithFormat:NSLocalizedString(@"LoginFailed", nil),code, desc]];
            }
        }];
    });
 
}


+ (NSString *)getUsersig:(NSString *)userId {
    return @"请填写正确的UserSig";
}

#pragma mark - pick delegate
- (NSInteger)numberOfComponentsInPickerView:(UIPickerView *)pickerView
{
    return 1;
}

- (NSInteger)pickerView:(UIPickerView *)pickerView numberOfRowsInComponent:(NSInteger)component
{
    return kUserCount;
}

- (NSString *)pickerView:(UIPickerView *)pickerView titleForRow:(NSInteger)row forComponent:(NSInteger)component
{
    return [NSString stringWithFormat:@"tiw_ios_%ld", row + 1];
}
@end
